@@ -9,8 +9,10 @@
 #include "splay.h"
 #include "wavelink.h"
 
+#include "wave_locale.h"
+
 extern GtkCTree *ctree_main;
-void treebox(char *title, GtkSignalFunc func);
+void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window);
 
 
 int mod_cnt;
@@ -474,7 +476,7 @@ if(anno_ctx)
 		}
 	}
 
-treebox("RTL Design Hierarchy", NULL);
+treebox("RTL Design Hierarchy", NULL, NULL);
 
 gtk_main();
 
@@ -482,8 +484,17 @@ return(0);
 }
 
 /*
- * $Id: stem_recurse.c,v 1.2 2007/04/20 02:08:10 gtkwave Exp $
+ * $Id: stem_recurse.c,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
  * $Log: stem_recurse.c,v $
+ * Revision 1.2  2007/08/26 21:35:39  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.1  2007/08/22 02:26:19  gtkwave
+ * treebox fixes to match revised gtkwave headers
+ *
+ * Revision 1.1.1.1  2007/05/30 04:25:38  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:10  gtkwave
  * initial release
  *
