@@ -40,7 +40,6 @@ void 		ae2_import_masked(void);
  * texsim prototypes/libae2rw interfacing...
  */
 #define	MAXFACLEN 	 65536
-#define AE2_SECTION_SIZE 256
 typedef unsigned long	 FACIDX;
 
 struct facref
@@ -73,14 +72,33 @@ unsigned long	ae2_read_symbol_rows(AE2_HANDLE handle, unsigned long symbol_idx);
 unsigned long	ae2_read_symbol_length(AE2_HANDLE handle, unsigned long symbol_idx);
 unsigned long 	ae2_read_value(AE2_HANDLE handle, FACREF* fr, uint64_t cycle, char* value);
 uint64_t 	ae2_read_next_value(AE2_HANDLE handle, FACREF* fr, uint64_t cycle, char* value);
-void 		ae2_read_close(AE2_HANDLE handle);
+void 		ae2_read_end(AE2_HANDLE handle);
+
+unsigned long	ae2_read_num_sparse_rows(AE2_HANDLE handle, unsigned long symbol_idx, uint64_t cycle);
+uint64_t 	ae2_read_ith_sparse_row(AE2_HANDLE handle, unsigned long symbol_idx, uint64_t cycle, unsigned long idx);
+
 #endif
 
 #endif
 
 /*
- * $Id: ae2.h,v 1.2 2007/04/20 01:39:00 gtkwave Exp $
+ * $Id: ae2.h,v 1.4 2007/08/31 22:42:43 gtkwave Exp $
  * $Log: ae2.h,v $
+ * Revision 1.4  2007/08/31 22:42:43  gtkwave
+ * 3.1.0 RC3 updates
+ *
+ * Revision 1.3  2007/08/26 21:35:39  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.1  2007/07/28 19:50:39  kermin
+ * Merged in the main line
+ *
+ * Revision 1.2  2007/06/23 02:37:27  gtkwave
+ * static section size is now dynamic
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:30  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 01:39:00  gtkwave
  * initial release
  *
