@@ -6,11 +6,13 @@
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  */
+
 /* AIX may need this for alloca to work */ 
 #if defined _AIX
   #pragma alloca
 #endif
 
+#include "globals.h"
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,15 +29,10 @@
 #define strcasecmp _stricmp
 #endif
 
-unsigned int default_flags=TR_RJUSTIFY;
-Times        tims = {0, 0, 0, 0, 0, 0, 0};
-Traces       traces = {0, 0, NULL, NULL, NULL, NULL, 0};
 
 /*
  * extract last n levels of hierarchy
  */
-int hier_max_level=0;
-
 char *hier_extract(char *pnt, int levels)
 {
 int i, len;
@@ -66,7 +63,7 @@ for(i=0;i<len;i++)
 		}
 	else
 		{
-		if(ch==hier_delimeter) 
+		if(ch==GLOBALS->hier_delimeter) 
 			{
 			if(!only_nums_so_far) levels--;
 			if(!levels)
@@ -88,50 +85,50 @@ return(pnt); /* not as many levels as max, so give the full name.. */
  */
 static void AddTrace( Trptr t )
 {
-if(default_flags&TR_NUMMASK) t->flags=default_flags;
-	else t->flags=(t->flags&TR_NUMMASK)|default_flags;
+if(GLOBALS->default_flags&TR_NUMMASK) t->flags=GLOBALS->default_flags;
+	else t->flags=(t->flags&TR_NUMMASK)|GLOBALS->default_flags;
 
-if(default_flags & TR_FTRANSLATED)
+if(GLOBALS->default_flags & TR_FTRANSLATED)
 	{
-	t->f_filter = current_translate_file;
+	t->f_filter = GLOBALS->current_translate_file;
 	}
 else
-if(default_flags & TR_PTRANSLATED)
+if(GLOBALS->default_flags & TR_PTRANSLATED)
 	{
-	t->p_filter = current_translate_proc;
+	t->p_filter = GLOBALS->current_translate_proc;
 	}
 
 
-if(shift_timebase_default_for_add)
-	t->shift=shift_timebase_default_for_add;
+if(GLOBALS->shift_timebase_default_for_add)
+	t->shift=GLOBALS->shift_timebase_default_for_add;
 
-if(!shadow_active)
+if(!GLOBALS->shadow_active)
 	{
-	if( traces.first == NULL )
+	if( GLOBALS->traces.first == NULL )
 		{
 		t->t_next = t->t_prev = NULL;
-		traces.first = traces.last = t;
+		GLOBALS->traces.first = GLOBALS->traces.last = t;
 	      	}
 	    	else
 	      	{
 		t->t_next = NULL;
-		t->t_prev = traces.last;
-		traces.last->t_next = t;
-		traces.last = t;
+		t->t_prev = GLOBALS->traces.last;
+		GLOBALS->traces.last->t_next = t;
+		GLOBALS->traces.last = t;
 	      	}
-	traces.total++;
+	GLOBALS->traces.total++;
 	}
 	else	/* hide offscreen */
 	{
 	struct strace *st = calloc_2(1, sizeof(struct strace));
-	st->next = shadow_straces;
-	st->value = shadow_type;
+	st->next = GLOBALS->shadow_straces;
+	st->value = GLOBALS->shadow_type;
 	st->trace = t;
 
-	st->string = shadow_string;	/* copy string over */
-	shadow_string = NULL;
+	st->string = GLOBALS->shadow_string;	/* copy string over */
+	GLOBALS->shadow_string = NULL;
 
-	shadow_straces = st;
+	GLOBALS->shadow_straces = st;
 	}
 }
 
@@ -168,7 +165,7 @@ if( (t = (Trptr) calloc_2( 1, sizeof( TraceEnt ))) == NULL )
 	return( 0 );
       	}
 AddTrace(t);
-t->flags = TR_BLANK | (default_flags & (TR_COLLAPSED|TR_ANALOG_BLANK_STRETCH));
+t->flags = TR_BLANK | (GLOBALS->default_flags & (TR_COLLAPSED|TR_ANALOG_BLANK_STRETCH));
 if(t->flags & TR_ANALOG_BLANK_STRETCH)
 	{
 	t->flags &= ~TR_BLANK;
@@ -214,25 +211,25 @@ if((comm=precondition_string(comment)))
 	t->is_alias=1;
 	}
 
-if(!traces.first)
+if(!GLOBALS->traces.first)
 	{
-	traces.first=traces.last=t;
-	traces.total=1;
+	GLOBALS->traces.first=GLOBALS->traces.last=t;
+	GLOBALS->traces.total=1;
 	return(1);
 	}
 	else
 	{
-	tb.buffer=traces.buffer;
-	tb.bufferlast=traces.bufferlast;
-	tb.buffercount=traces.buffercount;
+	tb.buffer=GLOBALS->traces.buffer;
+	tb.bufferlast=GLOBALS->traces.bufferlast;
+	tb.buffercount=GLOBALS->traces.buffercount;
 	
-	traces.buffer=traces.bufferlast=t;
-	traces.buffercount=1;
+	GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=t;
+	GLOBALS->traces.buffercount=1;
 	PasteBuffer();
 
-	traces.buffer=tb.buffer;
-	traces.bufferlast=tb.bufferlast;
-	traces.buffercount=tb.buffercount;
+	GLOBALS->traces.buffer=tb.buffer;
+	GLOBALS->traces.bufferlast=tb.bufferlast;
+	GLOBALS->traces.buffercount=tb.buffercount;
 
 	return(1);
 	}
@@ -251,9 +248,9 @@ int AddNodeTraceReturn(nptr nd, char *aliasname, Trptr *tret)
     int i;
 
     if(!nd) return(0); /* passed it a null node ptr by mistake */
-    if(nd->mvlfac) import_trace(nd);
+    if(nd->mv.mvlfac) import_trace(nd);
 
-    signalwindow_width_dirty=1;
+    GLOBALS->signalwindow_width_dirty=1;
     
     if( (t = (Trptr) calloc_2( 1, sizeof( TraceEnt ))) == NULL )
       {
@@ -307,13 +304,13 @@ if(aliasname)
 	}
 	else
 	{
-    	if(!hier_max_level) 
+    	if(!GLOBALS->hier_max_level) 
 		{
 		t->name = nd->nname;
 		}
 		else
 		{
-		t->name = hier_extract(nd->nname, hier_max_level);
+		t->name = hier_extract(nd->nname, GLOBALS->hier_max_level);
 		}
 	}
 
@@ -339,12 +336,34 @@ if(aliasname)
   }
 
 
+/* single node */
 int AddNode(nptr nd, char *aliasname)
 {
 return(AddNodeTraceReturn(nd, aliasname, NULL));
 }
 
 
+/* add multiple nodes (if array) */
+int AddNodeUnroll(nptr nd, char *aliasname)
+{
+if(nd->array_height <= 1)
+	{
+	return(AddNodeTraceReturn(nd, aliasname, NULL));
+	}
+	else
+	{
+	int i;
+	int rc = 1;
+
+	for(i=0;i<nd->array_height;i++)
+		{
+		rc |= AddNodeTraceReturn(nd+i, aliasname, NULL);
+		}
+	return(rc);
+	}
+}
+
+
 /*
  * Adds a vector to the display...
  */
@@ -355,7 +374,7 @@ int AddVector( bvptr vec )
 
     if(!vec) return(0); /* must've passed it a null pointer by mistake */
 
-    signalwindow_width_dirty=1;
+    GLOBALS->signalwindow_width_dirty=1;
 
     n = vec->nbits;
     t = (Trptr) calloc_2(1, sizeof( TraceEnt ) );
@@ -366,13 +385,13 @@ int AddVector( bvptr vec )
 	return( 0 );
       }
 
-    if(!hier_max_level)
+    if(!GLOBALS->hier_max_level)
 	{	
     	t->name = vec->name;
 	}
 	else
 	{
-	t->name = hier_extract(vec->name, hier_max_level);
+	t->name = hier_extract(vec->name, GLOBALS->hier_max_level);
 	}
     t->flags = ( n > 3 ) ? TR_HEX|TR_RJUSTIFY : TR_BIN|TR_RJUSTIFY;
     t->vector = TRUE;
@@ -387,13 +406,13 @@ int AddVector( bvptr vec )
  */
 void FreeTrace(Trptr t)
 {
-if(straces)
+if(GLOBALS->straces)
 	{
 	struct strace_defer_free *sd = calloc_2(1, sizeof(struct strace_defer_free));
-	sd->next = strace_defer_free_head;
+	sd->next = GLOBALS->strace_defer_free_head;
 	sd->defer = t;
 
-	strace_defer_free_head = sd;
+	GLOBALS->strace_defer_free_head = sd;
 	return;
 	}
 
@@ -443,14 +462,14 @@ free_2( t );
  */ 
 void RemoveTrace( Trptr t, int dofree )
   {
-    traces.total--;
-    if( t == traces.first )
+    GLOBALS->traces.total--;
+    if( t == GLOBALS->traces.first )
       {
-	traces.first = t->t_next;
+	GLOBALS->traces.first = t->t_next;
 	if( t->t_next )
             t->t_next->t_prev = NULL;
         else
-            traces.last = NULL;
+            GLOBALS->traces.last = NULL;
       }
     else
       {
@@ -458,7 +477,7 @@ void RemoveTrace( Trptr t, int dofree )
         if( t->t_next )
             t->t_next->t_prev = t->t_prev;
         else
-            traces.last = t->t_prev;
+            GLOBALS->traces.last = t->t_prev;
       }
     
     if(dofree)
@@ -475,7 +494,7 @@ void FreeCutBuffer(void)
 {
 Trptr t, t2;
 
-t=traces.buffer;
+t=GLOBALS->traces.buffer;
 
 while(t)
 	{
@@ -484,8 +503,8 @@ while(t)
 	t=t2;	
 	}
 
-traces.buffer=traces.bufferlast=NULL;
-traces.buffercount=0;
+GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=NULL;
+GLOBALS->traces.buffercount=0;
 }
 
 
@@ -499,9 +518,9 @@ Trptr CutBuffer(void)
 Trptr t, tnext;
 Trptr first=NULL, current=NULL;
 
-shift_click_trace=NULL;		/* so shift-clicking doesn't explode */
+GLOBALS->shift_click_trace=NULL;		/* so shift-clicking doesn't explode */
 
-t=traces.first;
+t=GLOBALS->traces.first;
 while(t)
 	{
 	if((t->flags)&(TR_HIGHLIGHT)) break;
@@ -509,14 +528,14 @@ while(t)
 	}
 if(!t) return(NULL);	/* keeps a double cut from blowing out the buffer */
 
-signalwindow_width_dirty=1;
+GLOBALS->signalwindow_width_dirty=1;
 
 FreeCutBuffer();
 
 /*
  * propagate cut for whole comment group if comment selected and collapsed...
  */
-t=traces.first;
+t=GLOBALS->traces.first;
 while(t)
 	{
 	top_of_cut:
@@ -549,14 +568,14 @@ while(t)
 	t=t->t_next;
 	}
 
-t=traces.first;
+t=GLOBALS->traces.first;
 while(t)
 	{
 	tnext=t->t_next;
 	if(t->flags&TR_HIGHLIGHT)
 		{
-		traces.bufferlast=t;
-		traces.buffercount++;
+		GLOBALS->traces.bufferlast=t;
+		GLOBALS->traces.buffercount++;
 
 		t->flags&=(~TR_HIGHLIGHT);
 		RemoveTrace(t, 0);
@@ -577,7 +596,7 @@ while(t)
 	t=tnext;
 	}
 
-return(traces.buffer=first);
+return(GLOBALS->traces.buffer=first);
 }
 
 
@@ -589,24 +608,24 @@ Trptr PasteBuffer(void)
 {
 Trptr t, tinsert=NULL, tinsertnext;
 
-if(!traces.buffer) return(NULL);
+if(!GLOBALS->traces.buffer) return(NULL);
 
-signalwindow_width_dirty=1;
+GLOBALS->signalwindow_width_dirty=1;
 
-if(!(t=traces.first))
+if(!(t=GLOBALS->traces.first))
 	{
-	t=traces.last=traces.first=traces.buffer;
+	t=GLOBALS->traces.last=GLOBALS->traces.first=GLOBALS->traces.buffer;
 	while(t)
 		{
-		traces.last=t;
-		traces.total++;
+		GLOBALS->traces.last=t;
+		GLOBALS->traces.total++;
 		t=t->t_next;
 		}	
 
-	traces.buffer=traces.bufferlast=NULL;
-	traces.buffercount=0;
+	GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=NULL;
+	GLOBALS->traces.buffercount=0;
 
-	return(traces.first);
+	return(GLOBALS->traces.first);
 	}
 
 while(t)
@@ -634,27 +653,27 @@ while(t)
 nxtl:	t=t->t_next;
 	}
 
-if(!tinsert) tinsert=traces.last;
+if(!tinsert) tinsert=GLOBALS->traces.last;
 
 tinsertnext=tinsert->t_next;
-tinsert->t_next=traces.buffer;
-traces.buffer->t_prev=tinsert;
-traces.bufferlast->t_next=tinsertnext;
-traces.total+=traces.buffercount;
+tinsert->t_next=GLOBALS->traces.buffer;
+GLOBALS->traces.buffer->t_prev=tinsert;
+GLOBALS->traces.bufferlast->t_next=tinsertnext;
+GLOBALS->traces.total+=GLOBALS->traces.buffercount;
 
 if(!tinsertnext)
 	{
-	traces.last=traces.bufferlast;
+	GLOBALS->traces.last=GLOBALS->traces.bufferlast;
 	}
 	else
 	{
-	tinsertnext->t_prev=traces.bufferlast;
+	tinsertnext->t_prev=GLOBALS->traces.bufferlast;
 	}
 
-traces.buffer=traces.bufferlast=NULL;
-traces.buffercount=0;
+GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=NULL;
+GLOBALS->traces.buffercount=0;
 
-return(traces.first);
+return(GLOBALS->traces.first);
 }
 
 
@@ -666,36 +685,36 @@ Trptr PrependBuffer(void)
 {
 Trptr t, prev;
 
-if(!traces.buffer) return(NULL);
+if(!GLOBALS->traces.buffer) return(NULL);
 
-signalwindow_width_dirty=1;
+GLOBALS->signalwindow_width_dirty=1;
 
-t=traces.buffer;
+t=GLOBALS->traces.buffer;
 
 while(t)
 	{
 	prev=t;
 	t->flags&=(~TR_HIGHLIGHT);
-	traces.total++;
+	GLOBALS->traces.total++;
 	t=t->t_next;
 	}
 
-if((prev->t_next=traces.first))
+if((prev->t_next=GLOBALS->traces.first))
 	{
 	/* traces.last current value is ok as it stays the same */
-	traces.first->t_prev=prev; /* but we need the reverse link back up */
+	GLOBALS->traces.first->t_prev=prev; /* but we need the reverse link back up */
 	}
 	else
 	{
-	traces.last=prev;
+	GLOBALS->traces.last=prev;
 	}
 
-traces.first=traces.buffer;
+GLOBALS->traces.first=GLOBALS->traces.buffer;
 
-traces.buffer=traces.bufferlast=NULL;
-traces.buffercount=0;
+GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=NULL;
+GLOBALS->traces.buffercount=0;
 
-return(traces.first);
+return(GLOBALS->traces.first);
 }
 
 
@@ -708,11 +727,11 @@ Trptr t;
 Trptr *tsort, *tsort_pnt;
 int i;
    
-if(!traces.total) return(0);
+if(!GLOBALS->traces.total) return(0);
 
-t=traces.first;
-tsort=tsort_pnt=wave_alloca(sizeof(Trptr)*traces.total);   
-for(i=0;i<traces.total;i++)
+t=GLOBALS->traces.first;
+tsort=tsort_pnt=wave_alloca(sizeof(Trptr)*GLOBALS->traces.total);   
+for(i=0;i<GLOBALS->traces.total;i++)
         {
         if(!t)
                 {
@@ -724,13 +743,13 @@ for(i=0;i<traces.total;i++)
         t=t->t_next;
         }
 
-traces.first=*(--tsort_pnt);
+GLOBALS->traces.first=*(--tsort_pnt);
 
-for(i=traces.total-1;i>=0;i--)
+for(i=GLOBALS->traces.total-1;i>=0;i--)
         {
         t=*tsort_pnt;
 
-	if(i==traces.total-1)
+	if(i==GLOBALS->traces.total-1)
 		{
 		t->t_prev=NULL;
 		}
@@ -745,8 +764,8 @@ for(i=traces.total-1;i>=0;i--)
 		}
         }
 
-traces.last=*tsort;
-traces.last->t_next=NULL;
+GLOBALS->traces.last=*tsort;
+GLOBALS->traces.last->t_next=NULL;
 
 return(1);
 }  
@@ -852,11 +871,11 @@ char *subst, ch;
 int i;
 int (*cptr)(const void*, const void*);
    
-if(!traces.total) return(0);
+if(!GLOBALS->traces.total) return(0);
 
-t=traces.first;
-tsort=tsort_pnt=wave_alloca(sizeof(Trptr)*traces.total);   
-for(i=0;i<traces.total;i++)
+t=GLOBALS->traces.first;
+tsort=tsort_pnt=wave_alloca(sizeof(Trptr)*GLOBALS->traces.total);   
+for(i=0;i<GLOBALS->traces.total;i++)
         {
         if(!t)
                 {
@@ -868,7 +887,7 @@ for(i=0;i<traces.total;i++)
 	if((subst=t->name))
 	        while((ch=(*subst)))
         	        {
-        	        if(ch==hier_delimeter) { *subst=VCDNAM_HIERSORT; } /* forces sort at hier boundaries */
+        	        if(ch==GLOBALS->hier_delimeter) { *subst=VCDNAM_HIERSORT; } /* forces sort at hier boundaries */
         	        subst++;
         	        }
 
@@ -882,16 +901,16 @@ switch(mode)
 	default:	cptr=tracesignamecompare; break;
 	}
 
-qsort(tsort, traces.total, sizeof(Trptr), cptr);
+qsort(tsort, GLOBALS->traces.total, sizeof(Trptr), cptr);
 
 tsort_pnt=tsort;
-for(i=0;i<traces.total;i++)
+for(i=0;i<GLOBALS->traces.total;i++)
         {
         t=*(tsort_pnt++);
 
 	if(!i)
 		{
-		traces.first=t;
+		GLOBALS->traces.first=t;
 		t->t_prev=NULL;
 		}
 		else
@@ -905,12 +924,12 @@ for(i=0;i<traces.total;i++)
 	if((subst=t->name))
 	        while((ch=(*subst)))
         	        {
-        	        if(ch==VCDNAM_HIERSORT) { *subst=hier_delimeter; } /* restore hier */
+        	        if(ch==VCDNAM_HIERSORT) { *subst=GLOBALS->hier_delimeter; } /* restore hier */
         	        subst++;
         	        }
         }
 
-traces.last=prev;
+GLOBALS->traces.last=prev;
 prev->t_next=NULL;
 
 return(1);
@@ -1002,7 +1021,7 @@ return(rc);
 
 int UpdateTracesVisible(void)
 {
-Trptr t = traces.first;
+Trptr t = GLOBALS->traces.first;
 int cnt = 0;
 
 while(t)
@@ -1015,14 +1034,14 @@ while(t)
 	t=t->t_next;
 	}
 
-traces.visible = cnt;
+GLOBALS->traces.visible = cnt;
 return(cnt);
 }
 
 
 void CollapseAllGroups(void)
 {
-Trptr t = traces.first;
+Trptr t = GLOBALS->traces.first;
 int mode = 0;
 
 while(t)
@@ -1052,7 +1071,7 @@ UpdateTracesVisible();
 
 void ExpandAllGroups(void)
 {
-Trptr t = traces.first;
+Trptr t = GLOBALS->traces.first;
 
 while(t)
 	{
@@ -1064,8 +1083,34 @@ UpdateTracesVisible();
 }
 
 /*
- * $Id: analyzer.c,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: analyzer.c,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
  * $Log: analyzer.c,v $
+ * Revision 1.2  2007/08/26 21:35:39  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.4  2007/08/25 19:43:45  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.3  2007/08/07 03:18:54  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.2  2007/08/06 03:50:45  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:18  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:20  gtkwave
+ * Imported sources
+ *
+ * Revision 1.4  2007/05/28 00:55:05  gtkwave
+ * added support for arrays as a first class dumpfile datatype
+ *
+ * Revision 1.3  2007/04/29 04:13:49  gtkwave
+ * changed anon union defined in struct Node to a named one as anon unions
+ * are a gcc extension
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
