@@ -7,12 +7,15 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef ANALYZER_H
 #define ANALYZER_H
 
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include "wavealloca.h"
+#include "vlist.h"
 #include "debug.h"
 
 typedef struct _SearchProgressData {
@@ -136,12 +139,14 @@ struct Node
 
     hptr     *harray;   /* fill this in when we make a trace.. contains  */
 			/*  a ptr to an array of histents for bsearching */
-    int      numhist;	/* number of elements in the harray */
-
     union {
       struct fac *mvlfac; /* for use with mvlsim aets */
       struct vlist_t *mvlfac_vlist;
-    };
+      char *value;	/* for use when unrolling ae2 values */
+    } mv; 		/* anon union is a gcc extension so use mv instead.  using this union avoids crazy casting warnings */
+
+    int      numhist;	/* number of elements in the harray */
+    unsigned int array_height, this_row;
   };
 
 typedef struct BitAttributes
@@ -282,6 +287,7 @@ void ExpandAllGroups(void);
 void DisplayTraces(int val);
 int AddNodeTraceReturn(nptr nd, char *aliasname, Trptr *tret);
 int AddNode(nptr nd, char *aliasname);
+int AddNodeUnroll(nptr nd, char *aliasname);
 int AddVector(bvptr vec);
 int AddBlankTrace(char *commentname);
 int InsertBlankTrace(char *comment, int different_flags);
@@ -301,15 +307,10 @@ eptr ExpandNode(nptr n);
 void DeleteNode(nptr n);
 nptr ExtractNodeSingleBit(nptr n, int bit);
 
-extern Times       tims;
-extern Traces      traces;
-extern unsigned int default_flags;
-extern Trptr	   shift_click_trace;
 
 
 /* hierarchy depths */
 char *hier_extract(char *pnt, int levels);
-extern int hier_max_level;
 
 /* vector matching */
 char *attempt_vecmatch(char *s1, char *s2);
@@ -317,8 +318,27 @@ char *attempt_vecmatch(char *s1, char *s2);
 #endif
 
 /*
- * $Id: analyzer.h,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: analyzer.h,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.2  2007/08/26 21:35:39  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/25 19:43:45  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:18  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:50  gtkwave
+ * Imported sources
+ *
+ * Revision 1.4  2007/05/28 00:55:05  gtkwave
+ * added support for arrays as a first class dumpfile datatype
+ *
+ * Revision 1.3  2007/04/29 04:13:49  gtkwave
+ * changed anon union defined in struct Node to a named one as anon unions
+ * are a gcc extension
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
