@@ -7,8 +7,10 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
 #include <config.h>
 #include <math.h>
+#include <string.h>
 #include "gtk12compat.h"
 #include "currenttime.h"
 #include "pixmaps.h"
@@ -90,7 +92,7 @@ if(flags&TR_ASCII)
 
 	len=(nbits/8)+2+2;		/* $xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='"'; }
+	if(GLOBALS->show_base) { *(pnt++)='"'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
 
@@ -115,12 +117,12 @@ if(flags&TR_ASCII)
 		
 		parse+=8;
 		}
-	if (!found && !show_base) {
+	if (!found && !GLOBALS->show_base) {
 		*(pnt++)='"';
 		*(pnt++)='"';
 	}
 		
-	if(show_base) { *(pnt++)='"'; }
+	if(GLOBALS->show_base) { *(pnt++)='"'; }
 	*(pnt++)=0x00;
 	}
 else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
@@ -129,7 +131,7 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 
 	len=(nbits/4)+2+1;		/* $xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='$'; }
+	if(GLOBALS->show_base) { *(pnt++)='$'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
 
@@ -251,7 +253,7 @@ else if(flags&TR_OCT)
 
 	len=(nbits/3)+2+1;		/* #xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='#'; }
+	if(GLOBALS->show_base) { *(pnt++)='#'; }
 
 	parse=(flags&TR_RJUSTIFY)
 		?(newbuff+((nbits%3)?(nbits%3):3))
@@ -288,7 +290,7 @@ else if(flags&TR_BIN)
 
 	len=(nbits/1)+2+1;		/* %xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='%'; }
+	if(GLOBALS->show_base) { *(pnt++)='%'; }
 
 	parse=newbuff+3;
 
@@ -372,7 +374,7 @@ else if(flags&TR_REAL)
 		{
 rl_go_binary:	len=(nbits/1)+2+1;		/* %xxxxx */
 		os=pnt=(char *)calloc_2(1,len);
-		if(show_base) { *(pnt++)='%'; }
+		if(GLOBALS->show_base) { *(pnt++)='%'; }
 	
 		parse=newbuff+3;
 	
@@ -611,7 +613,7 @@ if(flags&TR_ASCII)
 
 	len=(nbits/8)+2+2;		/* $xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='"'; }
+	if(GLOBALS->show_base) { *(pnt++)='"'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
 
@@ -635,12 +637,12 @@ if(flags&TR_ASCII)
 		
 		parse+=8;
 		}
-	if (!found && !show_base) {
+	if (!found && !GLOBALS->show_base) {
 		*(pnt++)='"';
 		*(pnt++)='"';
 	}
 		
-	if(show_base) { *(pnt++)='"'; }
+	if(GLOBALS->show_base) { *(pnt++)='"'; }
 	*(pnt++)=0x00;
 	}
 else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
@@ -649,7 +651,7 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 
 	len=(nbits/4)+2+1;		/* $xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='$'; }
+	if(GLOBALS->show_base) { *(pnt++)='$'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
 
@@ -771,7 +773,7 @@ else if(flags&TR_OCT)
 
 	len=(nbits/3)+2+1;		/* #xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='#'; }
+	if(GLOBALS->show_base) { *(pnt++)='#'; }
 
 	parse=(flags&TR_RJUSTIFY)
 		?(newbuff+((nbits%3)?(nbits%3):3))
@@ -807,7 +809,7 @@ else if(flags&TR_BIN)
 
 	len=(nbits/1)+2+1;		/* %xxxxx */
 	os=pnt=(char *)calloc_2(1,len);
-	if(show_base) { *(pnt++)='%'; }
+	if(GLOBALS->show_base) { *(pnt++)='%'; }
 
 	parse=newbuff+3;
 
@@ -891,7 +893,7 @@ else if(flags&TR_REAL)
 		{
 rl_go_binary:	len=(nbits/1)+2+1;		/* %xxxxx */
 		os=pnt=(char *)calloc_2(1,len);
-		if(show_base) { *(pnt++)='%'; }
+		if(GLOBALS->show_base) { *(pnt++)='%'; }
 	
 		parse=newbuff+3;
 	
@@ -939,13 +941,27 @@ return(os);
 
 static char *dofilter(Trptr t, char *s)
 {
-xl_file_filter[t->f_filter] = xl_splay(s, xl_file_filter[t->f_filter]);
+GLOBALS->xl_file_filter[t->f_filter] = xl_splay(s, GLOBALS->xl_file_filter[t->f_filter]);
 	
-if(!strcasecmp(s, xl_file_filter[t->f_filter]->item))
+if(!strcasecmp(s, GLOBALS->xl_file_filter[t->f_filter]->item))
 	{
 	free_2(s);
-	s = malloc_2(strlen(xl_file_filter[t->f_filter]->trans) + 1);
-	strcpy(s, xl_file_filter[t->f_filter]->trans);
+	s = malloc_2(strlen(GLOBALS->xl_file_filter[t->f_filter]->trans) + 1);
+	strcpy(s, GLOBALS->xl_file_filter[t->f_filter]->trans);
+	}
+
+if((*s == '?') && (!GLOBALS->color_active_in_filter))
+	{
+	char *s2a;
+	char *s2 = strchr(s+1, '?');
+	if(s2)
+		{
+		s2++;
+		s2a = malloc_2(strlen(s2)+1);
+		strcpy(s2a, s2);
+		free_2(s);
+		s = s2a;
+		}
 	}
 
 return(s);
@@ -954,7 +970,7 @@ return(s);
 #if !defined _MSC_VER && !defined __MINGW32__
 static char *pdofilter(Trptr t, char *s)
 {
-struct pipe_ctx *p = proc_filter[t->p_filter];
+struct pipe_ctx *p = GLOBALS->proc_filter[t->p_filter];
 char buf[1025];
 int n;
 
@@ -982,6 +998,19 @@ if(p)
 		}
 	}	
 
+if((*s == '?') && (!GLOBALS->color_active_in_filter))
+	{
+	char *s2a;
+	char *s2 = strchr(s+1, '?');
+	if(s2)
+		{
+		s2++;
+		s2a = malloc_2(strlen(s2)+1);
+		strcpy(s2a, s2);
+		free_2(s);
+		s = s2a;
+		}
+	}
 return(s);
 }
 #endif
@@ -1326,8 +1355,33 @@ return(retval);
 }
 
 /*
- * $Id: baseconvert.c,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: baseconvert.c,v 1.3 2007/08/26 21:35:39 gtkwave Exp $
  * $Log: baseconvert.c,v $
+ * Revision 1.3  2007/08/26 21:35:39  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.5  2007/08/25 19:43:45  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.4  2007/08/07 03:18:54  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.3  2007/08/06 03:50:45  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.2  2007/08/05 02:27:18  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1.2.1  2007/07/28 19:50:39  kermin
+ * Merged in the main line
+ *
+ * Revision 1.2  2007/07/23 23:13:08  gtkwave
+ * adds for color tags in filtered trace data
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:50  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
