@@ -12,6 +12,7 @@
   #pragma alloca
 #endif
 
+#include "globals.h" 
 #include <config.h>
 #include "analyzer.h"
 #include "symbol.h"
@@ -25,6 +26,7 @@
 #include "translate.h"
 #include "ptranslate.h"
 #include "main.h"
+#include "menu.h"
 #include "busy.h"
 #include <stdlib.h>
 
@@ -169,12 +171,12 @@ void import_trace(nptr np)
 {
 set_window_busy(NULL);
 
-if(is_lxt)
+if(GLOBALS->is_lxt)
 	{
 	import_lxt_trace(np);
 	}
 else
-if(is_lx2)
+if(GLOBALS->is_lx2)
 	{
 	import_lx2_trace(np);
 	}
@@ -367,6 +369,7 @@ char ch, wild_active=0;
 int len;
 int i;
 int made=0;
+unsigned int rows = 0;
 
 pnt=str;
 while((ch=*pnt))
@@ -394,10 +397,10 @@ if(!wild_active)	/* short circuit wildcard evaluation with bsearch */
 		return(0);
 
 maketracespt2:
-		s=symfind(str+i);
+		s=symfind(str+i, &rows);
 		if(s)
 			{
-			nexp = ExtractNodeSingleBit(s->n, atoi(str+1));
+			nexp = ExtractNodeSingleBit(&s->n[rows], atoi(str+1));
 			if(nexp)
 				{
 				AddNode(nexp, NULL);
@@ -409,9 +412,9 @@ maketracespt2:
 		}
 		else
 		{
-		if((s=symfind(str)))
+		if((s=symfind(str, &rows)))
 			{
-			AddNode(s->n,NULL);
+			AddNode(&s->n[rows],NULL);
 			return(~0);
 			}
 			else
@@ -439,11 +442,11 @@ if(len)
 	memcpy(wild,str,len);
 	wave_regex_compile(wild, WAVE_REGEX_WILD);
 
-	for(i=0;i<numfacs;i++)
+	for(i=0;i<GLOBALS->numfacs;i++)
 		{
-		if(wave_regex_match(facs[i]->name, WAVE_REGEX_WILD))
+		if(wave_regex_match(GLOBALS->facs[i]->name, WAVE_REGEX_WILD))
 			{
-			AddNode(facs[i]->n,NULL);
+			AddNode(GLOBALS->facs[i]->n,NULL);
 			made=~0;
 			if(quick_return) break;
 			}
@@ -470,6 +473,7 @@ int len, nodepnt=0;
 int i;
 struct Node *n[512];
 struct Bits *b=NULL;
+unsigned int rows = 0;
 
 while(1)
 {
@@ -515,10 +519,10 @@ if(len)
 				if((wild[i]==')')&&(wild[i+1])) 
 					{
 					i++; 
-					s=symfind(wild+i);
+					s=symfind(wild+i, &rows);
 					if(s)
 						{
-						nexp = ExtractNodeSingleBit(s->n, atoi(wild+1));
+						nexp = ExtractNodeSingleBit(&s->n[rows], atoi(wild+1));
 						if(nexp)
 							{
 							n[nodepnt++]=nexp;
@@ -531,9 +535,9 @@ if(len)
 			}
 			else
 			{
-			if((s=symfind(wild)))	
+			if((s=symfind(wild, &rows)))	
 				{
-				n[nodepnt++]=s->n;
+				n[nodepnt++]=&s->n[rows];
 				if(nodepnt==512) { free_2(wild); goto ifnode; }
 				}
 			}
@@ -541,11 +545,11 @@ if(len)
 		else
 		{
 		wave_regex_compile(wild, WAVE_REGEX_WILD);
-		for(i=numfacs-1;i>=0;i--)	/* to keep vectors in little endian hi..lo order */
+		for(i=GLOBALS->numfacs-1;i>=0;i--)	/* to keep vectors in little endian hi..lo order */
 			{
-			if(wave_regex_match(facs[i]->name, WAVE_REGEX_WILD))
+			if(wave_regex_match(GLOBALS->facs[i]->name, WAVE_REGEX_WILD))
 				{
-				n[nodepnt++]=facs[i]->n;
+				n[nodepnt++]=GLOBALS->facs[i]->n;
 				if(nodepnt==512) { free_2(wild); goto ifnode; }
 				}
 			}
@@ -566,7 +570,7 @@ if(nodepnt)
 	for(i=0;i<nodepnt;i++)
 		{
 		b->nodes[i]=n[i];
-		if(n[i]->mvlfac) import_trace(n[i]);
+		if(n[i]->mv.mvlfac) import_trace(n[i]);
 		}
 
 	b->nbits=nodepnt;
@@ -589,6 +593,7 @@ struct Node *n[512];
 struct BitAttributes ba[512];
 struct Bits *b=NULL;
 int state = 0;
+unsigned int rows = 0;
 
 while(1)
 {
@@ -641,10 +646,10 @@ if(len)
 				if((wild[i]==')')&&(wild[i+1])) 
 					{
 					i++; 
-					s=symfind(wild+i);
+					s=symfind(wild+i, &rows);
 					if(s)
 						{
-						nexp = ExtractNodeSingleBit(s->n, atoi(wild+1));
+						nexp = ExtractNodeSingleBit(&s->n[rows], atoi(wild+1));
 						if(nexp)
 							{
 							n[nodepnt++]=nexp;
@@ -657,9 +662,9 @@ if(len)
 			}
 			else
 			{
-			if((s=symfind(wild)))	
+			if((s=symfind(wild, &rows)))	
 				{
-				n[nodepnt++]=s->n;
+				n[nodepnt++]=&s->n[rows];
 				}
 			}
 		}
@@ -682,7 +687,7 @@ if(nodepnt)
 	for(i=0;i<nodepnt;i++)
 		{
 		b->nodes[i]=n[i];
-		if(n[i]->mvlfac) import_trace(n[i]);
+		if(n[i]->mv.mvlfac) import_trace(n[i]);
 
 		b->attribs[i].shift = ba[i].shift;
 		b->attribs[i].flags = ba[i].flags;
@@ -707,20 +712,20 @@ struct Node *n[512];
 struct Bits *b=NULL;
 
 if(!direction)
-for(i=numfacs-1;i>=0;i--)	/* to keep vectors in hi..lo order */
+for(i=GLOBALS->numfacs-1;i>=0;i--)	/* to keep vectors in hi..lo order */
 	{
-	if(facs[i]->selected)
+	if(GLOBALS->facs[i]->selected)
 		{
-		n[nodepnt++]=facs[i]->n;
+		n[nodepnt++]=GLOBALS->facs[i]->n;
 		if((nodepnt==512)||(numrows==nodepnt)) break;
 		}
 	}
 else
-for(i=0;i<numfacs;i++)		/* to keep vectors in lo..hi order */
+for(i=0;i<GLOBALS->numfacs;i++)		/* to keep vectors in lo..hi order */
 	{
-	if(facs[i]->selected)
+	if(GLOBALS->facs[i]->selected)
 		{
-		n[nodepnt++]=facs[i]->n;
+		n[nodepnt++]=GLOBALS->facs[i]->n;
 		if((nodepnt==512)||(numrows==nodepnt)) break;
 		}
 	}
@@ -733,7 +738,7 @@ if(nodepnt)
 	for(i=0;i<nodepnt;i++)
 		{
 		b->nodes[i]=n[i];
-		if(n[i]->mvlfac) import_trace(n[i]);
+		if(n[i]->mv.mvlfac) import_trace(n[i]);
 		}
 
 	b->nbits=nodepnt;
@@ -787,9 +792,9 @@ struct Bits *b=NULL;
 struct symbol *symhi = NULL, *symlo = NULL;
 char hier_delimeter2;
 
-if(!vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
+if(!GLOBALS->vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
 	{
-	hier_delimeter2=hier_delimeter;
+	hier_delimeter2=GLOBALS->hier_delimeter;
 	}
 	else
 	{
@@ -798,7 +803,7 @@ if(!vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
 
 n=(struct Node **)wave_alloca(len*sizeof(struct Node *));
 
-if(!autocoalesce_reversal)		/* normal case for MTI */
+if(!GLOBALS->autocoalesce_reversal)		/* normal case for MTI */
 	{
 	symhi=sym;
 	while(sym)
@@ -829,7 +834,7 @@ if(nodepnt)
 	for(i=0;i<nodepnt;i++)
 		{
 		b->nodes[i]=n[i];
-		if(n[i]->mvlfac) import_trace(n[i]);
+		if(n[i]->mv.mvlfac) import_trace(n[i]);
 		}
 
 	b->nbits=nodepnt;
@@ -886,7 +891,7 @@ if(nodepnt)
 			int add1, add2, totallen;
 
 			add1=l1-root1len; add2=l2-root2len;
-			if(vcd_explicit_zero_subscripts==-1)
+			if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 				{
 				add1--;
 				add2--;
@@ -907,7 +912,7 @@ if(nodepnt)
 					+1		/* add 0x00	      */
 					;
 
-				if(vcd_explicit_zero_subscripts==-1)
+				if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 					{
 					fixup1=*(s1+l1-1); *(s1+l1-1)=0;
 					fixup2=*(s2+l2-1); *(s2+l2-1)=0;
@@ -917,7 +922,7 @@ if(nodepnt)
 				strncpy(b->name,s1,root1len-1);
 				sprintf(b->name+root1len-1,"[%s:%s]",s1+root1len, s2+root2len);
 
-				if(vcd_explicit_zero_subscripts==-1)
+				if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 					{
 					*(s1+l1-1)=fixup1;
 					*(s2+l2-1)=fixup2;
@@ -936,7 +941,7 @@ if(nodepnt)
 					+1		/* add 0x00	      */
 					;
 
-				if(vcd_explicit_zero_subscripts==-1)
+				if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 					{
 					fixup1=*(s1+l1-1); *(s1+l1-1)=0;
 					}
@@ -945,7 +950,7 @@ if(nodepnt)
 				strncpy(b->name,s1,root1len-1);
 				sprintf(b->name+root1len-1,"[%s]",s1+root1len);
 
-				if(vcd_explicit_zero_subscripts==-1)
+				if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 					{
 					*(s1+l1-1)=fixup1;
 					}
@@ -1009,13 +1014,13 @@ struct Bits *b=NULL;
 if(!direction)
 for(i=hi;i>=lo;i--)	/* to keep vectors in hi..lo order */
 	{
-	n[nodepnt++]=facs[i]->n;
+	n[nodepnt++]=GLOBALS->facs[i]->n;
 	if(nodepnt==512) break;
 	}
 else
 for(i=lo;i<=hi;i++)	/* to keep vectors in lo..hi order */
 	{
-	n[nodepnt++]=facs[i]->n;
+	n[nodepnt++]=GLOBALS->facs[i]->n;
 	if(nodepnt==512) break;
 	}
 
@@ -1027,7 +1032,7 @@ if(nodepnt)
 	for(i=0;i<nodepnt;i++)
 		{
 		b->nodes[i]=n[i];
-		if(n[i]->mvlfac) import_trace(n[i]);
+		if(n[i]->mv.mvlfac) import_trace(n[i]);
 		}
 
 	b->nbits=nodepnt;
@@ -1044,26 +1049,26 @@ if(nodepnt)
 
 		if(!direction)
 			{
-			s1=facs[hi]->n->nname;
-			s2=facs[lo]->n->nname;
+			s1=GLOBALS->facs[hi]->n->nname;
+			s2=GLOBALS->facs[lo]->n->nname;
 			}
 			else
 			{
-			s1=facs[lo]->n->nname;
-			s2=facs[hi]->n->nname;
+			s1=GLOBALS->facs[lo]->n->nname;
+			s2=GLOBALS->facs[hi]->n->nname;
 			}
 		
 		l1=strlen(s1); 
 
 		for(i=l1-1;i>=0;i--)
 			{
-			if(s1[i]==hier_delimeter) { root1len=i+1; break; }
+			if(s1[i]==GLOBALS->hier_delimeter) { root1len=i+1; break; }
 			}
 
 		l2=strlen(s2);	
 		for(i=l2-1;i>=0;i--)
 			{
-			if(s2[i]==hier_delimeter) { root2len=i+1; break; }
+			if(s2[i]==GLOBALS->hier_delimeter) { root2len=i+1; break; }
 			}
 
 		if((root1len!=root2len)||(!root1len)||(!root2len)||
@@ -1163,7 +1168,7 @@ if(lo!=hi)
 	}
 	else
 	{
-	return(AddNode(facs[lo]->n,NULL));
+	return(AddNode(GLOBALS->facs[lo]->n,NULL));
 	}
 }
 
@@ -1438,16 +1443,16 @@ char *s1, *s2;
 int root1len=0, root2len=0;
 int l1, l2;
 
-if(!vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
+if(!GLOBALS->vcd_explicit_zero_subscripts)	/* 0==yes, -1==no */
 	{
-	hier_delimeter2=hier_delimeter;
+	hier_delimeter2=GLOBALS->hier_delimeter;
 	}
 	else
 	{
 	hier_delimeter2='[';
 	}
 
-if(!autocoalesce_reversal)		/* normal case for MTI */
+if(!GLOBALS->autocoalesce_reversal)		/* normal case for MTI */
 	{
 	symhi=sym;
 	while(sym)
@@ -1501,7 +1506,7 @@ if((root1len!=root2len)||(!root1len)||(!root2len)||
 	int add1, add2, totallen;
 
 	add1=l1-root1len; add2=l2-root2len;
-	if(vcd_explicit_zero_subscripts==-1)
+	if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 		{
 		add1--;
 		add2--;
@@ -1522,7 +1527,7 @@ if((root1len!=root2len)||(!root1len)||(!root2len)||
 			+1		/* add 0x00	      */
 			;
 
-		if(vcd_explicit_zero_subscripts==-1)
+		if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 			{
 			fixup1=*(s1+l1-1); *(s1+l1-1)=0;
 			fixup2=*(s2+l2-1); *(s2+l2-1)=0;
@@ -1532,7 +1537,7 @@ if((root1len!=root2len)||(!root1len)||(!root2len)||
 		strncpy(name,s1,root1len-1);
 		sprintf(name+root1len-1,"[%s:%s]",s1+root1len, s2+root2len);
 
-		if(vcd_explicit_zero_subscripts==-1)
+		if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 			{
 			*(s1+l1-1)=fixup1;
 			*(s2+l2-1)=fixup2;
@@ -1551,7 +1556,7 @@ if((root1len!=root2len)||(!root1len)||(!root2len)||
 			+1		/* add 0x00	      */
 			;
 
-		if(vcd_explicit_zero_subscripts==-1)
+		if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 			{
 			fixup1=*(s1+l1-1); *(s1+l1-1)=0;
 			}
@@ -1560,7 +1565,7 @@ if((root1len!=root2len)||(!root1len)||(!root2len)||
 		strncpy(name,s1,root1len-1);
 		sprintf(name+root1len-1,"[%s]",s1+root1len);
 
-		if(vcd_explicit_zero_subscripts==-1)
+		if(GLOBALS->vcd_explicit_zero_subscripts==-1)
 			{
 			*(s1+l1-1)=fixup1;
 			}
@@ -1585,7 +1590,7 @@ int offset, len;
 eptr rc=NULL;
 exptr exp;
 
-if(n->mvlfac) import_trace(n);
+if(n->mv.mvlfac) import_trace(n);
 
 DEBUG(fprintf(stderr, "expanding '%s'\n", n->nname));
 if(!n->ext)
@@ -1622,7 +1627,7 @@ if(!n->ext)
 		}
 	if(i>-1) offset=i;
 
-	nam=(char *)wave_alloca(offset+20);
+	nam=(char *)wave_alloca(offset+20+30);
 	memcpy(nam, n->nname, offset);
 
 	if(!n->harray)         /* make quick array lookup for aet display--normally this is done in addnode */
@@ -1671,6 +1676,12 @@ if(!n->ext)
 		{
 		narray[i] = (nptr)calloc_2(1, sizeof(struct Node));
 		sprintf(nam+offset, "[%d]", actual);	
+		if(n->array_height)
+			{
+			len = offset + strlen(nam+offset);
+			sprintf(nam+len, "{%d}", n->this_row);
+			}
+
 		len = offset + strlen(nam+offset);
 		narray[i]->nname = (char *)malloc_2(len+1);
 		strcpy(narray[i]->nname, nam);
@@ -1686,7 +1697,7 @@ if(!n->ext)
 	for(i=0;i<n->numhist;i++)
 		{
 		h=n->harray[i];
-		if((h->time<min_time)||(h->time>max_time))
+		if((h->time<GLOBALS->min_time)||(h->time>GLOBALS->max_time))
 			{
 			for(j=0;j<width;j++)
 				{
@@ -1769,7 +1780,7 @@ char *nam;
 int offset, len;
 exptr exp;
 
-if(n->mvlfac) import_trace(n);
+if(n->mv.mvlfac) import_trace(n);
 
 DEBUG(fprintf(stderr, "expanding '%s'\n", n->nname));
 if(!n->ext)
@@ -1850,7 +1861,14 @@ if(!n->ext)
 
 	np = (nptr)calloc_2(1, sizeof(struct Node));
 	sprintf(nam+offset, "[%d]", actual);
+        if(n->array_height)
+        	{
+                len = offset + strlen(nam+offset);
+                sprintf(nam+len, "{%d}", n->this_row);
+                }
 	len = offset + strlen(nam+offset);
+
+
 	np->nname = (char *)malloc_2(len+1);
 	strcpy(np->nname, nam);
 
@@ -1863,7 +1881,7 @@ if(!n->ext)
 	for(i=0;i<n->numhist;i++)
 		{
 		h=n->harray[i];
-		if((h->time<min_time)||(h->time>max_time))
+		if((h->time<GLOBALS->min_time)||(h->time>GLOBALS->max_time))
 			{
 			if(np->curr)
 				{
@@ -1976,7 +1994,7 @@ if(w)
 		*lbrack = *colon = *rbrack = 0;
 		msbs = lbrack + 1;
 		lsbs = colon + 1;
-		rname = hier_extract(w, hier_max_level);
+		rname = hier_extract(w, GLOBALS->hier_max_level);
 
 		msb = atoi(msbs);
 		lsb = atoi(lsbs);
@@ -2049,6 +2067,7 @@ int len;
 char *prefix, *suffix;
 char *w2;
 nptr nexp;
+unsigned int rows = 0;
 
 if(!(len=strlen(w))) return(0);
 if(*(w+len-1)=='\n')
@@ -2076,7 +2095,7 @@ if(*w2=='*')
 	TimeType ttlocal;
 	int which=0;
 
-	zoom_was_explicitly_set=~0;
+	GLOBALS->zoom_was_explicitly_set=~0;
 	w2++;
 
 	for(;;)
@@ -2084,15 +2103,15 @@ if(*w2=='*')
 		while(*w2==' ') w2++;
 		if(*w2==0) return(~0);
 
-		if(!which) { sscanf(w2,"%f",&f); tims.zoom=(gdouble)f; }
+		if(!which) { sscanf(w2,"%f",&f); GLOBALS->tims.zoom=(gdouble)f; }
 		else
 		{
 		sscanf(w2,TTFormat,&ttlocal);
 		switch(which)
 			{
-			case 1:  tims.marker=ttlocal; break;
+			case 1:  GLOBALS->tims.marker=ttlocal; break;
 			default: 
-				if((which-2)<26) named_markers[which-2]=ttlocal; 
+				if((which-2)<26) GLOBALS->named_markers[which-2]=ttlocal; 
 				break;
 			}
 		}
@@ -2115,16 +2134,16 @@ else
 if(*w2=='>')
 	{
 	char *nptr=(*(w2+1)!=0)?(w2+1):NULL;
-	shift_timebase_default_for_add=nptr?atoi_64(nptr):LLDescriptor(0);
+	GLOBALS->shift_timebase_default_for_add=nptr?atoi_64(nptr):LLDescriptor(0);
 	}
 else
 if(*w2=='@')
 	{
 	/* handle trace flags */
-	sscanf(w2+1, "%x", &default_flags);
-	if( (default_flags & (TR_FTRANSLATED|TR_PTRANSLATED)) == (TR_FTRANSLATED|TR_PTRANSLATED) )
+	sscanf(w2+1, "%x", &GLOBALS->default_flags);
+	if( (GLOBALS->default_flags & (TR_FTRANSLATED|TR_PTRANSLATED)) == (TR_FTRANSLATED|TR_PTRANSLATED) )
 		{
-		default_flags &= ~TR_PTRANSLATED; /* safest bet though this is a cfg file error */
+		GLOBALS->default_flags &= ~TR_PTRANSLATED; /* safest bet though this is a cfg file error */
 		}
 
 	return(~0);
@@ -2146,8 +2165,8 @@ if(*w2=='+')
 		return(0);
 
 aliaspt2:
-		s=symfind(suffix+i);
-		nexp = ExtractNodeSingleBit(s->n, atoi(suffix+1));
+		s=symfind(suffix+i, &rows);
+		nexp = ExtractNodeSingleBit(&s->n[rows], atoi(suffix+1));
 		if(nexp)
 			{
 			AddNode(nexp, prefix+1);
@@ -2160,9 +2179,9 @@ aliaspt2:
 		}
 		else
 		{
-		if((s=symfind(suffix)))
+		if((s=symfind(suffix, &rows)))
 			{
-			AddNode(s->n,prefix+1);
+			AddNode(&s->n[rows],prefix+1);
 			return(~0);
 			}
 			else
@@ -2266,25 +2285,25 @@ if(*w2=='!')
 			{
 			if(ch=='!')
 				{
-				shadow_active = 0;
+				GLOBALS->shadow_active = 0;
 				return(~0);
 				}
 
-			if((!i)&&(shadow_straces))
+			if((!i)&&(GLOBALS->shadow_straces))
 				{
 				delete_strace_context();
 				}
 
-			shadow_logical_mutex[i] = (ch & 1);
+			GLOBALS->shadow_logical_mutex[i] = (ch & 1);
 			}
 			else	/* in case of short read */
 			{
-			shadow_logical_mutex[i] = 0;
+			GLOBALS->shadow_logical_mutex[i] = 0;
 			}
 		}
 
-	shadow_mark_idx_start = 0;
-	shadow_mark_idx_end = 0;
+	GLOBALS->shadow_mark_idx_start = 0;
+	GLOBALS->shadow_mark_idx_end = 0;
 
 	if(i==6)
 		{
@@ -2292,18 +2311,18 @@ if(*w2=='!')
 		if(ch != 0)
 			{
 			if (isupper(ch) || ch=='@')
-				shadow_mark_idx_start = ch - '@';
+				GLOBALS->shadow_mark_idx_start = ch - '@';
 		
 			ch = *(w2+8);
 			if(ch != 0)
 				{
 				if (isupper(ch) || ch=='@')
-					shadow_mark_idx_end = ch - '@';
+					GLOBALS->shadow_mark_idx_end = ch - '@';
 				}
 			}
 		}
 
-	shadow_active = 1;
+	GLOBALS->shadow_active = 1;
 	return(~0);
 	}
 	else
@@ -2313,22 +2332,22 @@ if(*w2=='?')
 	if(*(w2+1)=='\"')
 		{
 		int len = strlen(w2+2);
-		if(shadow_string) free_2(shadow_string);
-		shadow_string=NULL;
+		if(GLOBALS->shadow_string) free_2(GLOBALS->shadow_string);
+		GLOBALS->shadow_string=NULL;
 
 		if(len)
 			{
-			shadow_string = malloc_2(len+1);		
-			strcpy(shadow_string, w2+2);
+			GLOBALS->shadow_string = malloc_2(len+1);		
+			strcpy(GLOBALS->shadow_string, w2+2);
 			}
 
-		shadow_type = ST_STRING;
+		GLOBALS->shadow_type = ST_STRING;
 		}
 		else
 		{
 		int hex;
 		sscanf(w2+1, "%x", &hex);	
-		shadow_type = hex;
+		GLOBALS->shadow_type = hex;
 		}
 
 	return(~0);
@@ -2337,7 +2356,7 @@ else if(*w2=='^')
 	{
 	if(*(w2+1) == '>')
 		{
-		current_translate_proc = 0;	/* will overwrite if loadable/translatable */
+		GLOBALS->current_translate_proc = 0;	/* will overwrite if loadable/translatable */
 
 		if(*(w2+2) != '0')
 			{
@@ -2354,7 +2373,7 @@ else if(*w2=='^')
 		}
 		else
 		{
-		current_translate_file = 0;	/* will overwrite if loadable/translatable */
+		GLOBALS->current_translate_file = 0;	/* will overwrite if loadable/translatable */
 
 		if(*(w2+1) != '0')
 			{
@@ -2383,18 +2402,39 @@ else if (*w2 == '[')
     *w++ = 0;
     if (strcmp (w2, "size") == 0)
       {
+      if(!GLOBALS->ignore_savefile_size)
+	{
 	/* Main window size.  */
 	int x, y;
 	sscanf (w, "%d %d", &x, &y);
 	set_window_size (x, y);
+	}
       }
     else if (strcmp (w2, "pos") == 0)
       {
+      if(!GLOBALS->ignore_savefile_pos)
+	{
 	/* Main window position.  */
 	int x, y;
 	sscanf (w, "%d %d", &x, &y);
 	set_window_xypos (x, y);
+	}
       }
+#if WAVE_USE_GTK2
+    else if (strcmp (w2, "treeopen") == 0)
+	{
+	while(*w)
+		{
+		if(!isspace(*w))
+			{
+			break;
+			}
+		w++;
+		}
+
+	force_open_tree_node(w);
+	}
+#endif
     else
       {
 	/* Unknown attribute.  Forget it.  */
@@ -2466,7 +2506,7 @@ if(!wild_active)	/* short circuit wildcard evaluation with bsearch */
 		return(made);
 
 maketracespt2:
-		if((s=symfind(str+i)))
+		if((s=symfind(str+i, NULL)))
 			{
 			lx2_set_fac_process_mask(s->n);
 			made = ~0;
@@ -2475,7 +2515,7 @@ maketracespt2:
 		}
 		else
 		{
-		if((s=symfind(str)))
+		if((s=symfind(str, NULL)))
 			{
 			lx2_set_fac_process_mask(s->n);
 			made = ~0;
@@ -2502,11 +2542,11 @@ if(len)
 	memcpy(wild,str,len);
 	wave_regex_compile(wild, WAVE_REGEX_WILD);
 
-	for(i=0;i<numfacs;i++)
+	for(i=0;i<GLOBALS->numfacs;i++)
 		{
-		if(wave_regex_match(facs[i]->name, WAVE_REGEX_WILD))
+		if(wave_regex_match(GLOBALS->facs[i]->name, WAVE_REGEX_WILD))
 			{
-			lx2_set_fac_process_mask(facs[i]->n);
+			lx2_set_fac_process_mask(GLOBALS->facs[i]->n);
 			made = ~0;
 			if(quick_return) break;
 			}
@@ -2575,7 +2615,7 @@ if(len)
 				if((wild[i]==')')&&(wild[i+1])) 
 					{
 					i++; 
-					s=symfind(wild+i);
+					s=symfind(wild+i, NULL);
 					if(s)
 						{
 						lx2_set_fac_process_mask(s->n);
@@ -2587,7 +2627,7 @@ if(len)
 			}
 			else
 			{
-			if((s=symfind(wild)))	
+			if((s=symfind(wild, NULL)))	
 				{
 				lx2_set_fac_process_mask(s->n);
 				rc = 1;
@@ -2597,11 +2637,11 @@ if(len)
 		else
 		{
 		wave_regex_compile(wild, WAVE_REGEX_WILD);
-		for(i=numfacs-1;i>=0;i--)	/* to keep vectors in little endian hi..lo order */
+		for(i=GLOBALS->numfacs-1;i>=0;i--)	/* to keep vectors in little endian hi..lo order */
 			{
-			if(wave_regex_match(facs[i]->name, WAVE_REGEX_WILD))
+			if(wave_regex_match(GLOBALS->facs[i]->name, WAVE_REGEX_WILD))
 				{
-				lx2_set_fac_process_mask(facs[i]->n);
+				lx2_set_fac_process_mask(GLOBALS->facs[i]->n);
 				rc = 1;
 				}
 			}
@@ -2681,7 +2721,7 @@ if(*w2=='+')
 		return(0);
 
 aliaspt2:
-		s=symfind(suffix+i);
+		s=symfind(suffix+i, NULL);
 		if(s)
 			{
 			lx2_set_fac_process_mask(s->n);
@@ -2691,7 +2731,7 @@ aliaspt2:
 		}
 		else
 		{
-		if((s=symfind(suffix)))
+		if((s=symfind(suffix, NULL)))
 			{
 			lx2_set_fac_process_mask(s->n);
 			made = ~0;
@@ -2793,8 +2833,40 @@ return(made);
 /****************/
 
 /*
- * $Id: bitvec.c,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: bitvec.c,v 1.3 2007/08/26 21:35:39 gtkwave Exp $
  * $Log: bitvec.c,v $
+ * Revision 1.3  2007/08/26 21:35:39  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.5  2007/08/21 22:35:38  gtkwave
+ * prelim tree state merge
+ *
+ * Revision 1.1.1.1.2.4  2007/08/07 03:18:54  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.3  2007/08/06 03:50:45  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.2  2007/08/05 02:27:18  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1.2.1  2007/07/28 19:50:39  kermin
+ * Merged in the main line
+ *
+ * Revision 1.2  2007/07/23 23:13:08  gtkwave
+ * adds for color tags in filtered trace data
+ *
+ * Revision 1.1.1.1  2007/05/30 04:28:02  gtkwave
+ * Imported sources
+ *
+ * Revision 1.4  2007/05/28 00:55:05  gtkwave
+ * added support for arrays as a first class dumpfile datatype
+ *
+ * Revision 1.3  2007/04/29 04:13:49  gtkwave
+ * changed anon union defined in struct Node to a named one as anon unions
+ * are a gcc extension
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
