@@ -27,6 +27,8 @@
 #include <getopt.h>
 #endif
 
+#include "wave_locale.h"
+
 static char *match = NULL;
 static int matchlen = 0;
 static int names_only = 0;
@@ -304,8 +306,11 @@ return(rc);
 }
 
 /*
- * $Id: lxt2miner.c,v 1.2 2007/04/20 02:08:18 gtkwave Exp $
+ * $Id: lxt2miner.c,v 1.1.1.1 2007/05/30 04:28:25 gtkwave Exp $
  * $Log: lxt2miner.c,v $
+ * Revision 1.1.1.1  2007/05/30 04:28:25  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:18  gtkwave
  * initial release
  *
