@@ -30,6 +30,9 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+#include "wave_locale.h"
+
+#if !defined _MSC_VER && !defined __MINGW32__
 
 /* size *must* match in gtkwave */
 #define WAVE_PARTIAL_VCD_RING_BUFFER_SIZE (1024*1024)
@@ -257,9 +260,31 @@ if(shmid >= 0)
 return(0);
 }
 
+#else
+
+int main(int argc, char **argv)
+{
+#if defined _MSC_VER || defined __MINGW32__
+fprintf(stderr, "Sorry, this doesn't run under Win32!\n");
+#endif
+
+fprintf(stderr, "If you find that this program works on your platform, please report this to the maintainers.\n");
+
+return(255);
+}
+
+#endif
+
+
 /*
- * $Id: shmidcat.c,v 1.2 2007/04/20 02:08:18 gtkwave Exp $
+ * $Id: shmidcat.c,v 1.2 2007/08/31 22:50:47 gtkwave Exp $
  * $Log: shmidcat.c,v $
+ * Revision 1.2  2007/08/31 22:50:47  gtkwave
+ * update shmidcat for mingw32 compile (disabled)
+ *
+ * Revision 1.1.1.1  2007/05/30 04:28:18  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:18  gtkwave
  * initial release
  *
