@@ -13,6 +13,7 @@
   #pragma alloca
 #endif
 
+#include "globals.h"
 #include <config.h>
 #include <gtk/gtk.h>
 #include "gtk12compat.h"
@@ -23,34 +24,14 @@
 #include "busy.h"
 #include "debug.h"
 
-char hier_grouping=1;
-
-static GtkWidget *window;
-static GtkWidget *entry_main;
-static GtkWidget *clist;
-static char bundle_direction=0;
-static GtkSignalFunc cleanup;
-static int num_rows=0;
-static int selected_rows=0;
-
-static GtkWidget *window1;
-static GtkWidget *entry;
-static char *entrybox_text_local=NULL;
-static GtkSignalFunc cleanup_e;
-
-static struct tree *h_selectedtree=NULL;
-static struct tree *current_tree=NULL;
-static struct treechain *treechain=NULL;
-
-static int is_active=0;
 
 int hier_searchbox_is_active(void)
 {
-return(is_active);
+return(GLOBALS->is_active_hiersearch_c_1);
 }
 
 
-static void refresh_tree(struct tree *t) 
+void refresh_hier_tree(struct tree *t) 
 {
 struct tree *t2;
 GtkCList *cl;
@@ -60,17 +41,17 @@ int pixlen=0, maxpixlen=0;
 static char *dotdot="..";
 struct treechain *tc;
 
-gtk_clist_freeze(cl=GTK_CLIST(clist));
+gtk_clist_freeze(cl=GTK_CLIST(GLOBALS->clist_hiersearch_c_1));
 gtk_clist_clear(cl);
 
-num_rows=0;
+GLOBALS->num_rows_hiersearch_c_1=0;
 
-if(t!=treeroot)
+if(t!=GLOBALS->treeroot)
 	{
-	maxpixlen=gdk_string_measure(signalfont,(gchar *)(dotdot));
+	maxpixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(dotdot));
 	}
 
-if(!hier_grouping)
+if(!GLOBALS->hier_grouping)
 	{
         char *tmp, *tmp2, *tmp3;
 	t2=t;
@@ -86,17 +67,17 @@ if(!hier_grouping)
                         	else
 				if(t2->which!=-1)
 				{
-				if(facs[t2->which]->vec_root)
+				if(GLOBALS->facs[t2->which]->vec_root)
 					{
-					if(autocoalesce)
+					if(GLOBALS->autocoalesce)
 						{
-						if(facs[t2->which]->vec_root!=facs[t2->which])
+						if(GLOBALS->facs[t2->which]->vec_root!=GLOBALS->facs[t2->which])
 							{
 							t2=t2->next;
 							continue;
 							}
 
-						tmp2=makename_chain(facs[t2->which]);
+						tmp2=makename_chain(GLOBALS->facs[t2->which]);
 						tmp3=leastsig_hiername(tmp2);
 						tmp=wave_alloca(strlen(tmp3)+4);
 						strcpy(tmp,   "[] ");
@@ -120,11 +101,11 @@ if(!hier_grouping)
 	                        tmp=t2->name;
 	                        }
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
-			pixlen=gdk_string_measure(signalfont,(gchar *)(tmp));
+			pixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
 			}
 		maxpixlen=(pixlen>maxpixlen)?pixlen:maxpixlen;		
 		gtk_clist_set_row_data(cl, row,t2); 
-		num_rows++;
+		GLOBALS->num_rows_hiersearch_c_1++;
 		t2=t2->next;
 		}
 	}
@@ -139,17 +120,17 @@ if(!hier_grouping)
                         {
 			if(t2->which!=-1)
 				{
-				if(facs[t2->which]->vec_root)
+				if(GLOBALS->facs[t2->which]->vec_root)
 					{
-					if(autocoalesce)
+					if(GLOBALS->autocoalesce)
 						{
-						if(facs[t2->which]->vec_root!=facs[t2->which])
+						if(GLOBALS->facs[t2->which]->vec_root!=GLOBALS->facs[t2->which])
 							{
 							t2=t2->next;
 							continue;
 							}
 
-						tmp2=makename_chain(facs[t2->which]);
+						tmp2=makename_chain(GLOBALS->facs[t2->which]);
 						tmp3=leastsig_hiername(tmp2);
 						tmp=wave_alloca(strlen(tmp3)+4);
 						strcpy(tmp,   "[] ");
@@ -174,10 +155,10 @@ if(!hier_grouping)
 	                        }
 
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
-			pixlen=gdk_string_measure(signalfont,(gchar *)(tmp));
+			pixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
 			maxpixlen=(pixlen>maxpixlen)?pixlen:maxpixlen;		
 			gtk_clist_set_row_data(cl, row,t2); 
-			num_rows++;
+			GLOBALS->num_rows_hiersearch_c_1++;
                         }
 		t2=t2->next;
 		}
@@ -191,27 +172,27 @@ if(!hier_grouping)
                         strcpy(tmp,   "(+) ");
                         strcpy(tmp+4, t2->name);
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
-			pixlen=gdk_string_measure(signalfont,(gchar *)(tmp));
+			pixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
 			maxpixlen=(pixlen>maxpixlen)?pixlen:maxpixlen;		
 			gtk_clist_set_row_data(cl, row,t2); 
-			num_rows++;
+			GLOBALS->num_rows_hiersearch_c_1++;
                         }
 		t2=t2->next;
 		}
 	}
 
 
-if(t!=treeroot)
+if(t!=GLOBALS->treeroot)
 	{
 	row=gtk_clist_prepend(cl,(gchar **)&dotdot);
 	gtk_clist_set_row_data(cl, row,NULL); 
-	num_rows++;
+	GLOBALS->num_rows_hiersearch_c_1++;
 	}
 
-if(maxpixlen)gtk_clist_set_column_width(GTK_CLIST(clist),0,maxpixlen);
+if(maxpixlen)gtk_clist_set_column_width(GTK_CLIST(GLOBALS->clist_hiersearch_c_1),0,maxpixlen);
 gtk_clist_thaw(cl);
 
-if((tc=treechain))
+if((tc=GLOBALS->treechain_hiersearch_c_1))
 	{
 	char *buf;
 	char hier_str[2];
@@ -225,22 +206,22 @@ if((tc=treechain))
 		}
 
 	buf=calloc_2(1,len);
-	hier_str[0]=hier_delimeter;
+	hier_str[0]=GLOBALS->hier_delimeter;
 	hier_str[1]=0;
 
-	tc=treechain;
+	tc=GLOBALS->treechain_hiersearch_c_1;
 	while(tc)
 		{
 		strcat(buf,tc->label->name);
 		if(tc->next) strcat(buf,hier_str);
 		tc=tc->next;
 		}
-	gtk_entry_set_text(GTK_ENTRY(entry_main), buf);
+	gtk_entry_set_text(GTK_ENTRY(GLOBALS->entry_main_hiersearch_c_1), buf);
 	free_2(buf);
 	}
 	else
 	{
-	gtk_entry_set_text(GTK_ENTRY(entry_main),"");
+	gtk_entry_set_text(GTK_ENTRY(GLOBALS->entry_main_hiersearch_c_1),"");
 	}
 }
 
@@ -249,23 +230,25 @@ static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
   G_CONST_RETURN gchar *entry_text;
   int len;
-  entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+  entry_text = gtk_entry_get_text(GTK_ENTRY(GLOBALS->entry_hiersearch_c_2));
   DEBUG(printf("Entry contents: %s\n", entry_text));
-  if(!(len=strlen(entry_text))) entrybox_text_local=NULL;
-	else strcpy((entrybox_text_local=(char *)malloc_2(len+1)),entry_text);
+  if(!(len=strlen(entry_text))) GLOBALS->entrybox_text_local_hiersearch_c_1=NULL;
+	else strcpy((GLOBALS->entrybox_text_local_hiersearch_c_1=(char *)malloc_2(len+1)),entry_text);
 
-  gtk_grab_remove(window1);
-  gtk_widget_destroy(window1);
+  gtk_grab_remove(GLOBALS->window1_hiersearch_c_1);
+  gtk_widget_destroy(GLOBALS->window1_hiersearch_c_1);
+  GLOBALS->window1_hiersearch_c_1 = NULL;
 
-  cleanup_e();
+  GLOBALS->cleanup_e_hiersearch_c_1();
 }
 
 static void destroy_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
   DEBUG(printf("Entry Cancel\n"));
-  entrybox_text_local=NULL;
-  gtk_grab_remove(window1);
-  gtk_widget_destroy(window1);
+  GLOBALS->entrybox_text_local_hiersearch_c_1=NULL;
+  gtk_grab_remove(GLOBALS->window1_hiersearch_c_1);
+  gtk_widget_destroy(GLOBALS->window1_hiersearch_c_1);
+  GLOBALS->window1_hiersearch_c_1 = NULL;
 }
 
 static void entrybox_local(char *title, int width, char *default_text, int maxch, GtkSignalFunc func)
@@ -273,29 +256,27 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
     GtkWidget *vbox, *hbox;
     GtkWidget *button1, *button2;
 
-    cleanup_e=func;
+    GLOBALS->cleanup_e_hiersearch_c_1=func;
 
     /* create a new modal window */
-    window1 = gtk_window_new(disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    gtk_grab_add(window1);
-    gtk_widget_set_usize( GTK_WIDGET (window1), width, 60);
-    gtk_window_set_title(GTK_WINDOW (window1), title);
-    gtk_signal_connect(GTK_OBJECT (window1), "delete_event",
-                       (GtkSignalFunc) destroy_callback_e, NULL);
+    GLOBALS->window1_hiersearch_c_1 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
+    install_focus_cb(GLOBALS->window1_hiersearch_c_1, ((char *)&GLOBALS->window1_hiersearch_c_1) - ((char *)GLOBALS));
+
+    gtk_grab_add(GLOBALS->window1_hiersearch_c_1);
+    gtk_widget_set_usize( GTK_WIDGET (GLOBALS->window1_hiersearch_c_1), width, 60);
+    gtk_window_set_title(GTK_WINDOW (GLOBALS->window1_hiersearch_c_1), title);
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window1_hiersearch_c_1), "delete_event",(GtkSignalFunc) destroy_callback_e, NULL);
 
     vbox = gtk_vbox_new (FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (window1), vbox);
+    gtk_container_add (GTK_CONTAINER (GLOBALS->window1_hiersearch_c_1), vbox);
     gtk_widget_show (vbox);
 
-    entry = gtk_entry_new_with_max_length (maxch);
-    gtk_signal_connect(GTK_OBJECT(entry), "activate",
-		       GTK_SIGNAL_FUNC(enter_callback_e),
-		       entry);
-    gtk_entry_set_text (GTK_ENTRY (entry), default_text);
-    gtk_entry_select_region (GTK_ENTRY (entry),
-			     0, GTK_ENTRY(entry)->text_length);
-    gtk_box_pack_start (GTK_BOX (vbox), entry, TRUE, TRUE, 0);
-    gtk_widget_show (entry);
+    GLOBALS->entry_hiersearch_c_2 = gtk_entry_new_with_max_length (maxch);
+    gtkwave_signal_connect(GTK_OBJECT(GLOBALS->entry_hiersearch_c_2), "activate",GTK_SIGNAL_FUNC(enter_callback_e),GLOBALS->entry_hiersearch_c_2);
+    gtk_entry_set_text (GTK_ENTRY (GLOBALS->entry_hiersearch_c_2), default_text);
+    gtk_entry_select_region (GTK_ENTRY (GLOBALS->entry_hiersearch_c_2),0, GTK_ENTRY(GLOBALS->entry_hiersearch_c_2)->text_length);
+    gtk_box_pack_start (GTK_BOX (vbox), GLOBALS->entry_hiersearch_c_2, TRUE, TRUE, 0);
+    gtk_widget_show (GLOBALS->entry_hiersearch_c_2);
 
     hbox = gtk_hbox_new (FALSE, 1);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
@@ -303,27 +284,20 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
 
     button1 = gtk_button_new_with_label ("OK");
     gtk_widget_set_usize(button1, 100, -1);
-    gtk_signal_connect(GTK_OBJECT (button1), "clicked",
-			       GTK_SIGNAL_FUNC(enter_callback_e),
-			       NULL);
+    gtkwave_signal_connect(GTK_OBJECT (button1), "clicked", GTK_SIGNAL_FUNC(enter_callback_e), NULL);
     gtk_widget_show (button1);
     gtk_container_add (GTK_CONTAINER (hbox), button1);
     GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-    gtk_signal_connect_object (GTK_OBJECT (button1),
-                                "realize",
-                             (GtkSignalFunc) gtk_widget_grab_default,
-                             GTK_OBJECT (button1));
+    gtkwave_signal_connect_object (GTK_OBJECT (button1), "realize", (GtkSignalFunc) gtk_widget_grab_default, GTK_OBJECT (button1));
 
     button2 = gtk_button_new_with_label ("Cancel");
     gtk_widget_set_usize(button2, 100, -1);
-    gtk_signal_connect(GTK_OBJECT (button2), "clicked",
-			       GTK_SIGNAL_FUNC(destroy_callback_e),
-			       NULL);
+    gtkwave_signal_connect(GTK_OBJECT (button2), "clicked", GTK_SIGNAL_FUNC(destroy_callback_e), NULL);
     GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);
     gtk_widget_show (button2);
     gtk_container_add (GTK_CONTAINER (hbox), button2);
 
-    gtk_widget_show(window1);
+    gtk_widget_show(GLOBALS->window1_hiersearch_c_1);
 }
 
 /***************************************************************************/
@@ -332,37 +306,37 @@ static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
 int i;
  
-if(!h_selectedtree) return;
+if(!GLOBALS->h_selectedtree_hiersearch_c_1) return;
 
 set_window_busy(widget);
 
-for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
         {
         struct symbol *s;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=autocoalesce;
+		s->vec_root->selected=GLOBALS->autocoalesce;
 		}
         }
 
 /* LX2 */
-if(is_lx2)
+if(GLOBALS->is_lx2)
 	{
 	int pre_import = 0;
 
-	for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
 	        {
 	        struct symbol *s, *t;  
-	        s=facs[i];
+	        s=GLOBALS->facs[i];
 		t=s->vec_root;
-		if((t)&&(autocoalesce))
+		if((t)&&(GLOBALS->autocoalesce))
 			{
 			if(t->selected)
 				{
 				while(t)
 					{
-					if(t->n->mvlfac)
+					if(t->n->mv.mvlfac)
 						{
 						lx2_set_fac_process_mask(t->n);
 						pre_import++;
@@ -373,7 +347,7 @@ if(is_lx2)
 			}
 			else
 			{
-			if(s->n->mvlfac)
+			if(s->n->mv.mvlfac)
 				{
 				lx2_set_fac_process_mask(s->n);
 				pre_import++;
@@ -388,13 +362,13 @@ if(is_lx2)
 	}
 /* LX2 */
 
-for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
         {
 	int len;
         struct symbol *s, *t;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	t=s->vec_root;
-	if((t)&&(autocoalesce))
+	if((t)&&(GLOBALS->autocoalesce))
 		{
 		if(t->selected)
 			{
@@ -410,15 +384,15 @@ for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
 		}
 		else
 		{
-	        AddNode(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);  
 		}
         }
 
 set_window_idle(widget);
 
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
@@ -427,41 +401,41 @@ static void insert_callback(GtkWidget *widget, GtkWidget *nothing)
 Traces tcache;
 int i;
     
-if(!h_selectedtree) return;
+if(!GLOBALS->h_selectedtree_hiersearch_c_1) return;
 
-memcpy(&tcache,&traces,sizeof(Traces));
-traces.total=0; 
-traces.first=traces.last=NULL;
+memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
+GLOBALS->traces.total=0; 
+GLOBALS->traces.first=GLOBALS->traces.last=NULL;
 
 set_window_busy(widget);
 
-for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
         {
         struct symbol *s;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=autocoalesce;
+		s->vec_root->selected=GLOBALS->autocoalesce;
 		}
         }
 
 /* LX2 */
-if(is_lx2)
+if(GLOBALS->is_lx2)
 	{
 	int pre_import = 0;
 
-	for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
 	        {
 	        struct symbol *s, *t;  
-	        s=facs[i];
+	        s=GLOBALS->facs[i];
 		t=s->vec_root;
-		if((t)&&(autocoalesce))
+		if((t)&&(GLOBALS->autocoalesce))
 			{
 			if(t->selected)
 				{
 				while(t)
 					{
-					if(t->n->mvlfac)
+					if(t->n->mv.mvlfac)
 						{
 						lx2_set_fac_process_mask(t->n);
 						pre_import++;
@@ -472,7 +446,7 @@ if(is_lx2)
 			}
 			else
 			{
-			if(s->n->mvlfac)
+			if(s->n->mv.mvlfac)
 				{
 				lx2_set_fac_process_mask(s->n);
 				pre_import++;
@@ -487,13 +461,13 @@ if(is_lx2)
 	}
 /* LX2 */
 
-for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
         {
 	int len;
         struct symbol *s, *t;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	t=s->vec_root;
-	if((t)&&(autocoalesce))
+	if((t)&&(GLOBALS->autocoalesce))
 		{
 		if(t->selected)
 			{
@@ -509,28 +483,28 @@ for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
 		}
 		else
 		{
-	        AddNode(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);  
 		}
         }
 
 set_window_idle(widget);
 
-traces.buffercount=traces.total;
-traces.buffer=traces.first;
-traces.bufferlast=traces.last;
-traces.first=tcache.first;
-traces.last=tcache.last;
-traces.total=tcache.total;
+GLOBALS->traces.buffercount=GLOBALS->traces.total;
+GLOBALS->traces.buffer=GLOBALS->traces.first;
+GLOBALS->traces.bufferlast=GLOBALS->traces.last;
+GLOBALS->traces.first=tcache.first;
+GLOBALS->traces.last=tcache.last;
+GLOBALS->traces.total=tcache.total;
 
 PasteBuffer();
  
-traces.buffercount=tcache.buffercount;
-traces.buffer=tcache.buffer;
-traces.bufferlast=tcache.bufferlast;
+GLOBALS->traces.buffercount=tcache.buffercount;
+GLOBALS->traces.buffer=tcache.buffer;
+GLOBALS->traces.bufferlast=tcache.bufferlast;
 
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
@@ -540,41 +514,41 @@ Traces tcache;
 int i;
 Trptr tfirst=NULL, tlast=NULL;
 
-if(!h_selectedtree) return;
+if(!GLOBALS->h_selectedtree_hiersearch_c_1) return;
         
-memcpy(&tcache,&traces,sizeof(Traces));
-traces.total=0;
-traces.first=traces.last=NULL;  
+memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
+GLOBALS->traces.total=0;
+GLOBALS->traces.first=GLOBALS->traces.last=NULL;  
 
 set_window_busy(widget);
 
-for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
         {
         struct symbol *s;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=autocoalesce;
+		s->vec_root->selected=GLOBALS->autocoalesce;
 		}
         }
 
 /* LX2 */
-if(is_lx2)
+if(GLOBALS->is_lx2)
 	{
 	int pre_import = 0;
 
-	for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
 	        {
 	        struct symbol *s, *t;  
-	        s=facs[i];
+	        s=GLOBALS->facs[i];
 		t=s->vec_root;
-		if((t)&&(autocoalesce))
+		if((t)&&(GLOBALS->autocoalesce))
 			{
 			if(t->selected)
 				{
 				while(t)
 					{
-					if(t->n->mvlfac)
+					if(t->n->mv.mvlfac)
 						{
 						lx2_set_fac_process_mask(t->n);
 						pre_import++;
@@ -585,7 +559,7 @@ if(is_lx2)
 			}
 			else
 			{
-			if(s->n->mvlfac)
+			if(s->n->mv.mvlfac)
 				{
 				lx2_set_fac_process_mask(s->n);
 				pre_import++;
@@ -600,13 +574,13 @@ if(is_lx2)
 	}
 /* LX2 */
 
-for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
         {
 	int len;
         struct symbol *s, *t;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	t=s->vec_root;
-	if((t)&&(autocoalesce))
+	if((t)&&(GLOBALS->autocoalesce))
 		{
 		if(t->selected)
 			{
@@ -622,26 +596,26 @@ for(i=fetchlow(h_selectedtree)->which;i<=fetchhigh(h_selectedtree)->which;i++)
 		}
 		else
 		{
-	        AddNode(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);  
 		}
         }
  
 set_window_idle(widget);
 
-tfirst=traces.first; tlast=traces.last; /* cache for highlighting */
+tfirst=GLOBALS->traces.first; tlast=GLOBALS->traces.last; /* cache for highlighting */
 
-traces.buffercount=traces.total;
-traces.buffer=traces.first;
-traces.bufferlast=traces.last;
-traces.first=tcache.first;
-traces.last=tcache.last;
-traces.total=tcache.total;
+GLOBALS->traces.buffercount=GLOBALS->traces.total;
+GLOBALS->traces.buffer=GLOBALS->traces.first;
+GLOBALS->traces.bufferlast=GLOBALS->traces.last;
+GLOBALS->traces.first=tcache.first;
+GLOBALS->traces.last=tcache.last;
+GLOBALS->traces.total=tcache.total;
 
 PasteBuffer();
  
-traces.buffercount=tcache.buffercount;
-traces.buffer=tcache.buffer;
-traces.bufferlast=tcache.bufferlast;
+GLOBALS->traces.buffercount=tcache.buffercount;
+GLOBALS->traces.buffer=tcache.buffer;
+GLOBALS->traces.bufferlast=tcache.bufferlast;
         
 CutBuffer();
         
@@ -653,26 +627,26 @@ while(tfirst)
         }
         
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
 static void
 bundle_cleanup(GtkWidget *widget, gpointer data)
 {
-if(entrybox_text_local)  
+if(GLOBALS->entrybox_text_local_hiersearch_c_1)  
         {
         char *efix;
 
-	if(!strlen(entrybox_text_local))
+	if(!strlen(GLOBALS->entrybox_text_local_hiersearch_c_1))
 		{
         	DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
-        	fetchvex(h_selectedtree, bundle_direction);
+        	fetchvex(GLOBALS->h_selectedtree_hiersearch_c_1, GLOBALS->bundle_direction_hiersearch_c_1);
 		}
 		else
 		{         
-	        efix=entrybox_text_local;
+	        efix=GLOBALS->entrybox_text_local_hiersearch_c_1;
 	        while(*efix)
 	                {
 	                if(*efix==' ')
@@ -683,35 +657,35 @@ if(entrybox_text_local)
 	                }
 	
 	        DEBUG(printf("Bundle name is: %s\n",entrybox_text_local));
-	        add_vector_range(entrybox_text_local,
-	                        fetchlow(h_selectedtree)->which,
-	                        fetchhigh(h_selectedtree)->which,
-	                        bundle_direction);
+	        add_vector_range(GLOBALS->entrybox_text_local_hiersearch_c_1,
+	                        fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which,
+	                        fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which,
+	                        GLOBALS->bundle_direction_hiersearch_c_1);
 		}
-        free_2(entrybox_text_local);
+        free_2(GLOBALS->entrybox_text_local_hiersearch_c_1);
         }
         else
         {
         DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
-        fetchvex(h_selectedtree, bundle_direction);
+        fetchvex(GLOBALS->h_selectedtree_hiersearch_c_1, GLOBALS->bundle_direction_hiersearch_c_1);
         }  
 
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
 static void
 bundle_callback_generic(void)
 {
-if(!autoname_bundles)
+if(!GLOBALS->autoname_bundles)
 	{
 	entrybox_local("Enter Bundle Name",300,"",128,GTK_SIGNAL_FUNC(bundle_cleanup));
 	}
 	else
 	{
-	entrybox_text_local=NULL;
+	GLOBALS->entrybox_text_local_hiersearch_c_1=NULL;
 	bundle_cleanup(NULL, NULL);
 	}
 }
@@ -720,14 +694,14 @@ if(!autoname_bundles)
 static void
 bundle_callback_up(GtkWidget *widget, gpointer data)
 {
-bundle_direction=0;
+GLOBALS->bundle_direction_hiersearch_c_1=0;
 bundle_callback_generic();
 }
                 
 static void
 bundle_callback_down(GtkWidget *widget, gpointer data)
 {
-bundle_direction=1;
+GLOBALS->bundle_direction_hiersearch_c_1=1;
 bundle_callback_generic();
 }
 
@@ -738,42 +712,42 @@ static void select_row_callback(GtkWidget *widget, gint row, gint column,
 {
 struct tree *t;
 
-t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(clist), row);
+t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->clist_hiersearch_c_1), row);
 if(t)
 	{
-        h_selectedtree=t;
+        GLOBALS->h_selectedtree_hiersearch_c_1=t;
 	DEBUG(printf("Selected: %s\n",t->name));
 	if(t->child)
 		{
 		struct treechain *tc, *tc2;
 
-		tc=treechain;
+		tc=GLOBALS->treechain_hiersearch_c_1;
 		if(tc)
 			{
 			while(tc->next) tc=tc->next;			
 
     			tc2=calloc_2(1,sizeof(struct treechain));
 			tc2->label=t;
-			tc2->tree=current_tree;
+			tc2->tree=GLOBALS->current_tree_hiersearch_c_1;
 			tc->next=tc2;
 			}
 			else
 			{
-    			treechain=calloc_2(1,sizeof(struct treechain));
-    			treechain->tree=current_tree;
-			treechain->label=t;
+    			GLOBALS->treechain_hiersearch_c_1=calloc_2(1,sizeof(struct treechain));
+    			GLOBALS->treechain_hiersearch_c_1->tree=GLOBALS->current_tree_hiersearch_c_1;
+			GLOBALS->treechain_hiersearch_c_1->label=t;
 			}
 
-		current_tree=t->child;
-		refresh_tree(current_tree);
+		GLOBALS->current_tree_hiersearch_c_1=t->child;
+		refresh_hier_tree(GLOBALS->current_tree_hiersearch_c_1);
 		}
 	}
 	else
 	{
 	struct treechain *tc;
 
-	h_selectedtree=NULL;
-	tc=treechain;
+	GLOBALS->h_selectedtree_hiersearch_c_1=NULL;
+	tc=GLOBALS->treechain_hiersearch_c_1;
 	if(tc)
 		{
 		for(;;)
@@ -787,7 +761,7 @@ if(t)
 					}
 					else
 					{
-					current_tree=tc->next->tree;
+					GLOBALS->current_tree_hiersearch_c_1=tc->next->tree;
 					free_2(tc->next);
 					tc->next=NULL;
 					break;
@@ -796,13 +770,13 @@ if(t)
 				else
 				{
 				free_2(tc);
-				treechain=NULL;
-				current_tree=treeroot;
+				GLOBALS->treechain_hiersearch_c_1=NULL;
+				GLOBALS->current_tree_hiersearch_c_1=GLOBALS->treeroot;
 				break;
 				}
 					
 			}
-		refresh_tree(current_tree);
+		refresh_hier_tree(GLOBALS->current_tree_hiersearch_c_1);
 		}
 	}
 
@@ -813,8 +787,8 @@ static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
 {
 struct tree *t;
 
-t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(clist), row);
-h_selectedtree=NULL;
+t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->clist_hiersearch_c_1), row);
+GLOBALS->h_selectedtree_hiersearch_c_1=NULL;
 
 if(t)
 	{
@@ -829,8 +803,9 @@ if(t)
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-  is_active=0;
-  gtk_widget_destroy(window);
+  GLOBALS->is_active_hiersearch_c_1=0;
+  gtk_widget_destroy(GLOBALS->window_hiersearch_c_3);
+  GLOBALS->window_hiersearch_c_3 = NULL;
 }
 
 
@@ -848,21 +823,22 @@ void hier_searchbox(char *title, GtkSignalFunc func)
     GtkWidget *table;
     GtkTooltips *tooltips;
 
-    if(is_active) 
+    if(GLOBALS->is_active_hiersearch_c_1) 
 	{
-	gdk_window_raise(window->window);
+	gdk_window_raise(GLOBALS->window_hiersearch_c_3->window);
 	return;
 	}
 
-    is_active=1;
-    cleanup=func;
-    num_rows=selected_rows=0;
+    GLOBALS->is_active_hiersearch_c_1=1;
+    GLOBALS->cleanup_hiersearch_c_3=func;
+    GLOBALS->num_rows_hiersearch_c_1=GLOBALS->selected_rows_hiersearch_c_1=0;
 
     /* create a new modal window */
-    window = gtk_window_new(disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW (window), title);
-    gtk_signal_connect(GTK_OBJECT (window), "delete_event",
-                       (GtkSignalFunc) destroy_callback, NULL);
+    GLOBALS->window_hiersearch_c_3 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
+    install_focus_cb(GLOBALS->window_hiersearch_c_3, ((char *)&GLOBALS->window_hiersearch_c_3) - ((char *)GLOBALS));
+
+    gtk_window_set_title(GTK_WINDOW (GLOBALS->window_hiersearch_c_3), title);
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_hiersearch_c_3), "delete_event",(GtkSignalFunc) destroy_callback, NULL);
 
     tooltips=gtk_tooltips_new_2();
 
@@ -884,16 +860,16 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 
     gtk_box_pack_start (GTK_BOX (vbox1), label, TRUE, TRUE, 0);
 
-    entry_main = gtk_entry_new();
-    gtk_entry_set_editable(GTK_ENTRY(entry_main), FALSE);
-    gtk_widget_show (entry_main);
-    gtk_tooltips_set_tip_2(tooltips, entry_main, 
+    GLOBALS->entry_main_hiersearch_c_1 = gtk_entry_new();
+    gtk_entry_set_editable(GTK_ENTRY(GLOBALS->entry_main_hiersearch_c_1), FALSE);
+    gtk_widget_show (GLOBALS->entry_main_hiersearch_c_1);
+    gtk_tooltips_set_tip_2(tooltips, GLOBALS->entry_main_hiersearch_c_1, 
 		"The hierarchy is built here by clicking on the appropriate "
 		"items below in the scrollable window.  Click on \"..\" to "
 		"go up a level."
 		,NULL);
 
-    gtk_box_pack_start (GTK_BOX (vbox1), entry_main, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox1), GLOBALS->entry_main_hiersearch_c_1, TRUE, TRUE, 0);
     gtk_container_add (GTK_CONTAINER (frame1), vbox1);
 
     frame2 = gtk_frame_new (NULL);
@@ -904,17 +880,13 @@ void hier_searchbox(char *title, GtkSignalFunc func)
                         GTK_FILL | GTK_EXPAND,
                         GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
 
-    clist=gtk_clist_new_with_titles(1,titles);
-    gtk_clist_column_titles_passive(GTK_CLIST(clist)); 
+    GLOBALS->clist_hiersearch_c_1=gtk_clist_new_with_titles(1,titles);
+    gtk_clist_column_titles_passive(GTK_CLIST(GLOBALS->clist_hiersearch_c_1)); 
 
-    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_SINGLE);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "select_row",
-			       GTK_SIGNAL_FUNC(select_row_callback),
-			       NULL);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "unselect_row",
-			       GTK_SIGNAL_FUNC(unselect_row_callback),
-			       NULL);
-    gtk_widget_show (clist);
+    gtk_clist_set_selection_mode(GTK_CLIST(GLOBALS->clist_hiersearch_c_1), GTK_SELECTION_SINGLE);
+    gtkwave_signal_connect_object (GTK_OBJECT (GLOBALS->clist_hiersearch_c_1), "select_row",GTK_SIGNAL_FUNC(select_row_callback),NULL);
+    gtkwave_signal_connect_object (GTK_OBJECT (GLOBALS->clist_hiersearch_c_1), "unselect_row",GTK_SIGNAL_FUNC(unselect_row_callback),NULL);
+    gtk_widget_show (GLOBALS->clist_hiersearch_c_1);
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
@@ -924,7 +896,7 @@ void hier_searchbox(char *title, GtkSignalFunc func)
     gtk_widget_show(scrolled_win);
 
     /* gtk_scrolled_window_add_with_viewport doesn't seen to work right here.. */
-    gtk_container_add (GTK_CONTAINER (scrolled_win), clist);
+    gtk_container_add (GTK_CONTAINER (scrolled_win), GLOBALS->clist_hiersearch_c_1);
 
     gtk_container_add (GTK_CONTAINER (frame2), scrolled_win);
 
@@ -941,9 +913,7 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 
     button1 = gtk_button_new_with_label ("Append");
     gtk_container_border_width (GTK_CONTAINER (button1), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button1), "clicked",
-			       GTK_SIGNAL_FUNC(ok_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button1), "clicked",GTK_SIGNAL_FUNC(ok_callback),GTK_OBJECT (GLOBALS->window_hiersearch_c_3));
     gtk_widget_show (button1);
     gtk_tooltips_set_tip_2(tooltips, button1, 
 		"Add selected signals to end of the display on the main window.",NULL);
@@ -952,21 +922,17 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 
     button2 = gtk_button_new_with_label (" Insert ");
     gtk_container_border_width (GTK_CONTAINER (button2), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button2), "clicked",
-			       GTK_SIGNAL_FUNC(insert_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button2), "clicked",GTK_SIGNAL_FUNC(insert_callback),GTK_OBJECT (GLOBALS->window_hiersearch_c_3));
     gtk_widget_show (button2);
     gtk_tooltips_set_tip_2(tooltips, button2, 
 		"Add children after last highlighted signal on the main window.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, FALSE, 0);
 
-    if(vcd_explicit_zero_subscripts>=0)
+    if(GLOBALS->vcd_explicit_zero_subscripts>=0)
 	{
     	button3 = gtk_button_new_with_label (" Bundle Up ");
     	gtk_container_border_width (GTK_CONTAINER (button3), 3);
-    	gtk_signal_connect_object (GTK_OBJECT (button3), "clicked",
-			       GTK_SIGNAL_FUNC(bundle_callback_up),
-			       GTK_OBJECT (window));
+    	gtkwave_signal_connect_object (GTK_OBJECT (button3), "clicked",GTK_SIGNAL_FUNC(bundle_callback_up),GTK_OBJECT (GLOBALS->window_hiersearch_c_3));
     	gtk_widget_show (button3);
     	gtk_tooltips_set_tip_2(tooltips, button3, 
 		"Bundle children into a single bit vector with the topmost signal as the LSB and the lowest as the MSB.",NULL);
@@ -974,9 +940,7 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 
     	button3a = gtk_button_new_with_label (" Bundle Down ");
     	gtk_container_border_width (GTK_CONTAINER (button3a), 3);
-    	gtk_signal_connect_object (GTK_OBJECT (button3a), "clicked",
-			       GTK_SIGNAL_FUNC(bundle_callback_down),
-			       GTK_OBJECT (window));
+    	gtkwave_signal_connect_object (GTK_OBJECT (button3a), "clicked",GTK_SIGNAL_FUNC(bundle_callback_down),GTK_OBJECT (GLOBALS->window_hiersearch_c_3));
     	gtk_widget_show (button3a);
     	gtk_tooltips_set_tip_2(tooltips, button3a, 
 		"Bundle children into a single bit vector with the topmost signal as the MSB and the lowest as the LSB.",NULL);
@@ -985,9 +949,7 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 
     button4 = gtk_button_new_with_label (" Replace ");
     gtk_container_border_width (GTK_CONTAINER (button4), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button4), "clicked",
-			       GTK_SIGNAL_FUNC(replace_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button4), "clicked",GTK_SIGNAL_FUNC(replace_callback),GTK_OBJECT (GLOBALS->window_hiersearch_c_3));
     gtk_widget_show (button4);
     gtk_tooltips_set_tip_2(tooltips, button4, 
 		"Replace highlighted signals on the main window with children shown above.",NULL);
@@ -995,31 +957,71 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 
     button5 = gtk_button_new_with_label (" Exit ");
     gtk_container_border_width (GTK_CONTAINER (button5), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button5), "clicked",
-			       GTK_SIGNAL_FUNC(destroy_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button5), "clicked",GTK_SIGNAL_FUNC(destroy_callback),GTK_OBJECT (GLOBALS->window_hiersearch_c_3));
     gtk_tooltips_set_tip_2(tooltips, button5, 
 		"Do nothing and return to the main window.",NULL);
     gtk_widget_show (button5);
     gtk_box_pack_start (GTK_BOX (hbox), button5, TRUE, FALSE, 0);
 
     gtk_container_add (GTK_CONTAINER (frameh), hbox);
-    gtk_container_add (GTK_CONTAINER (window), table);
+    gtk_container_add (GTK_CONTAINER (GLOBALS->window_hiersearch_c_3), table);
 
-    gtk_widget_show(window);
+    gtk_widget_show(GLOBALS->window_hiersearch_c_3);
 
-    if(!current_tree) 
+    if(!GLOBALS->current_tree_hiersearch_c_1) 
 	{
-	current_tree=treeroot;
-    	h_selectedtree=NULL;
+	GLOBALS->current_tree_hiersearch_c_1=GLOBALS->treeroot;
+    	GLOBALS->h_selectedtree_hiersearch_c_1=NULL;
 	}
 
-    refresh_tree(current_tree);
+    refresh_hier_tree(GLOBALS->current_tree_hiersearch_c_1);
 }
 
 /*
- * $Id: hiersearch.c,v 1.2 2007/04/20 02:08:13 gtkwave Exp $
+ * $Id: hiersearch.c,v 1.4 2007/09/12 17:26:44 gtkwave Exp $
  * $Log: hiersearch.c,v $
+ * Revision 1.4  2007/09/12 17:26:44  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.3  2007/09/10 18:08:49  gtkwave
+ * tabs selection can swap dynamically based on external window focus
+ *
+ * Revision 1.2  2007/08/26 21:35:41  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.8  2007/08/23 02:19:49  gtkwave
+ * merge GLOBALS state from old hier_search widget into new one
+ *
+ * Revision 1.1.1.1.2.7  2007/08/18 21:51:57  gtkwave
+ * widget destroys and teardown of file formats which use external loaders
+ * and are outside of malloc_2/free_2 control
+ *
+ * Revision 1.1.1.1.2.6  2007/08/07 03:18:54  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.5  2007/08/06 03:50:47  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.4  2007/08/05 02:27:20  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
+ * Merge Complete - I hope
+ *
+ * Revision 1.1.1.1.2.2  2007/07/28 19:50:39  kermin
+ * Merged in the main line
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:30  gtkwave
+ * Imported sources
+ *
+ * Revision 1.4  2007/05/28 00:55:06  gtkwave
+ * added support for arrays as a first class dumpfile datatype
+ *
+ * Revision 1.3  2007/04/29 04:13:49  gtkwave
+ * changed anon union defined in struct Node to a named one as anon unions
+ * are a gcc extension
+ *
  * Revision 1.2  2007/04/20 02:08:13  gtkwave
  * initial release
  *
