@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef WAVE_LX2RDR_H
 #define WAVE_LX2RDR_H
 
@@ -26,7 +28,6 @@ int numtrans;
 nptr np;
 };
 
-extern unsigned char is_lx2;
 TimeType lx2_main(char *fname, char *skip_start, char *skip_end);
 void import_lx2_trace(nptr np);
 
@@ -36,8 +37,20 @@ void lx2_import_masked(void);
 #endif
 
 /*
- * $Id: lx2.h,v 1.2 2007/04/20 02:08:13 gtkwave Exp $
+ * $Id: lx2.h,v 1.2 2007/08/26 21:35:41 gtkwave Exp $
  * $Log: lx2.h,v $
+ * Revision 1.2  2007/08/26 21:35:41  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/25 19:43:45  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:21  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:21  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:13  gtkwave
  * initial release
  *
