@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef WAVE_PIPEIO_H
 #define WAVE_PIPEIO_H
 
@@ -33,8 +35,20 @@ void pipeio_destroy(struct pipe_ctx *p);
 #endif
 
 /*
- * $Id: pipeio.h,v 1.2 2007/04/20 02:08:13 gtkwave Exp $
+ * $Id: pipeio.h,v 1.2 2007/08/26 21:35:43 gtkwave Exp $
  * $Log: pipeio.h,v $
+ * Revision 1.2  2007/08/26 21:35:43  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/25 19:43:45  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:21  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:23  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:13  gtkwave
  * initial release
  *
