@@ -7,6 +7,7 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
 #include <config.h>
 #include <gtk/gtk.h>
 #include "gtk12compat.h"
@@ -15,27 +16,21 @@
 #include "pipeio.h"
 #include "debug.h"
 
-
 #ifdef _MSC_VER
 #define strcasecmp _stricmp
 #endif
 
-
-int current_translate_proc = 0;	/* for the viewer */
-static int current_filter = 0; 	/* in requester */
-int num_proc_filters = 0;
-char *procsel_filter[PROC_FILTER_MAX+1];
-struct pipe_ctx *proc_filter[PROC_FILTER_MAX+1];
-
-
 void init_proctrans_data(void)
 {
 int i;
 
+if(!GLOBALS->procsel_filter) { GLOBALS->procsel_filter = calloc_2(FILE_FILTER_MAX+1, sizeof(char *)); }
+if(!GLOBALS->proc_filter) { GLOBALS->proc_filter = calloc_2(FILE_FILTER_MAX+1, sizeof(struct pipe_ctx *)); }
+
 for(i=0;i<PROC_FILTER_MAX+1;i++)
 	{
-	procsel_filter[i] = NULL;
-	proc_filter[i] = NULL;
+	GLOBALS->procsel_filter[i] = NULL;
+	GLOBALS->proc_filter[i] = NULL;
 	}
 }
 
@@ -45,16 +40,16 @@ int i;
 
 for(i=1;i<PROC_FILTER_MAX+1;i++)
 	{
-	if(proc_filter[i])
+	if(GLOBALS->proc_filter[i])
 		{
-		pipeio_destroy(proc_filter[i]);
-		proc_filter[i] = NULL;
+		pipeio_destroy(GLOBALS->proc_filter[i]);
+		GLOBALS->proc_filter[i] = NULL;
 		}
 
-	if(procsel_filter[i])
+	if(GLOBALS->procsel_filter[i])
 		{
-		free_2(procsel_filter[i]);
-		procsel_filter[i] = NULL;
+		free_2(GLOBALS->procsel_filter[i]);
+		GLOBALS->procsel_filter[i] = NULL;
 		}
 	}
 }
@@ -69,19 +64,19 @@ void set_current_translate_proc(char *name) { }
 
 static void regen_display(void)
 {
-signalwindow_width_dirty=1;
+GLOBALS->signalwindow_width_dirty=1;
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
 void remove_proc_filter(int which, int regen)
 {
-if(proc_filter[which])
+if(GLOBALS->proc_filter[which])
 	{
-	pipeio_destroy(proc_filter[which]);
-	proc_filter[which] = NULL;
+	pipeio_destroy(GLOBALS->proc_filter[which]);
+	GLOBALS->proc_filter[which] = NULL;
 
 	if(regen)
 	        {
@@ -107,16 +102,16 @@ if(!f)
 
 remove_proc_filter(which, 0); /* should never happen from GUI, but possible from save files or other weirdness */
 
-proc_filter[which] = pipeio_create(name);
+GLOBALS->proc_filter[which] = pipeio_create(name);
 }
 
 void install_proc_filter(int which)
 {
 int found = 0;
 
-if(traces.first)  
+if(GLOBALS->traces.first)  
         {
-        Trptr t = traces.first;
+        Trptr t = GLOBALS->traces.first;
         while(t)
                 {
                 if(t->flags&TR_HIGHLIGHT)
@@ -148,35 +143,31 @@ if(found)
 
 /************************************************************************/
 
-static int is_active=0;
-static char *fcurr = NULL;
 
-static GtkWidget *window;
-static GtkWidget *clist;
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-is_active=0;
-gtk_widget_destroy(window);
-window = NULL;
+GLOBALS->is_active_ptranslate_c_2=0;
+gtk_widget_destroy(GLOBALS->window_ptranslate_c_5);
+GLOBALS->window_ptranslate_c_5 = NULL;
 }
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-install_proc_filter(current_filter);
+install_proc_filter(GLOBALS->current_filter_ptranslate_c_1);
 destroy_callback(widget, nothing);
 }
 
 static void select_row_callback(GtkWidget *widget, gint row, gint column,
 	GdkEventButton *event, gpointer data)
 {
-current_filter = row + 1;
+GLOBALS->current_filter_ptranslate_c_1 = row + 1;
 }
 
 static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
 	GdkEventButton *event, gpointer data)
 {
-current_filter = 0; /* none */
+GLOBALS->current_filter_ptranslate_c_1 = 0; /* none */
 }
 
 
@@ -185,15 +176,15 @@ static void add_filter_callback_2(GtkWidget *widget, GtkWidget *nothing)
 int i;
 GtkCList *cl;
 
-if(!filesel_ok) { return; }
+if(!GLOBALS->filesel_ok) { return; }
 
-if(*fileselbox_text)
+if(*GLOBALS->fileselbox_text)
 	{
-	for(i=0;i<num_proc_filters;i++)
+	for(i=0;i<GLOBALS->num_proc_filters;i++)
 		{
-		if(procsel_filter[i])
+		if(GLOBALS->procsel_filter[i])
 			{
-			if(!strcmp(procsel_filter[i], *fileselbox_text)) 
+			if(!strcmp(GLOBALS->procsel_filter[i], *GLOBALS->fileselbox_text)) 
 				{
 				status_text("Filter already imported.\n");
 				return;
@@ -202,36 +193,36 @@ if(*fileselbox_text)
 		}
 	}
 
-num_proc_filters++;
-load_proc_filter(num_proc_filters, *fileselbox_text);
-if(proc_filter[num_proc_filters])
+GLOBALS->num_proc_filters++;
+load_proc_filter(GLOBALS->num_proc_filters, *GLOBALS->fileselbox_text);
+if(GLOBALS->proc_filter[GLOBALS->num_proc_filters])
 	{
-	if(procsel_filter[num_proc_filters]) free_2(procsel_filter[num_proc_filters]);
-	procsel_filter[num_proc_filters] = malloc_2(strlen(*fileselbox_text) + 1);
-	strcpy(procsel_filter[num_proc_filters], *fileselbox_text);
+	if(GLOBALS->procsel_filter[GLOBALS->num_proc_filters]) free_2(GLOBALS->procsel_filter[GLOBALS->num_proc_filters]);
+	GLOBALS->procsel_filter[GLOBALS->num_proc_filters] = malloc_2(strlen(*GLOBALS->fileselbox_text) + 1);
+	strcpy(GLOBALS->procsel_filter[GLOBALS->num_proc_filters], *GLOBALS->fileselbox_text);
 
-	cl=GTK_CLIST(clist);
+	cl=GTK_CLIST(GLOBALS->clist_ptranslate_c_2);
 	gtk_clist_freeze(cl);
-	gtk_clist_append(cl,(gchar **)&(procsel_filter[num_proc_filters]));
+	gtk_clist_append(cl,(gchar **)&(GLOBALS->procsel_filter[GLOBALS->num_proc_filters]));
 
 	gtk_clist_set_column_width(cl,0,gtk_clist_optimal_column_width(cl,0));
 	gtk_clist_thaw(cl);
 	}
 	else
 	{
-	num_proc_filters--;
+	GLOBALS->num_proc_filters--;
 	}
 }
 
 static void add_filter_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-if(num_proc_filters == PROC_FILTER_MAX)
+if(GLOBALS->num_proc_filters == PROC_FILTER_MAX)
 	{
 	status_text("Max number of process filters installed already.\n");
 	return;
 	}
 
-fileselbox("Select Filter Process",&fcurr,GTK_SIGNAL_FUNC(add_filter_callback_2), GTK_SIGNAL_FUNC(NULL),"*", 0);
+fileselbox("Select Filter Process",&GLOBALS->fcurr_ptranslate_c_1,GTK_SIGNAL_FUNC(add_filter_callback_2), GTK_SIGNAL_FUNC(NULL),"*", 0);
 }
 
 /*
@@ -249,20 +240,21 @@ void ptrans_searchbox(char *title)
     GtkWidget *table;
     GtkTooltips *tooltips;
 
-    if(is_active) 
+    if(GLOBALS->is_active_ptranslate_c_2) 
 	{
-	gdk_window_raise(window->window);
+	gdk_window_raise(GLOBALS->window_ptranslate_c_5->window);
 	return;
 	}
 
-    is_active=1;
-    current_filter = 0;
+    GLOBALS->is_active_ptranslate_c_2=1;
+    GLOBALS->current_filter_ptranslate_c_1 = 0;
 
     /* create a new modal window */
-    window = gtk_window_new(disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW (window), title);
-    gtk_signal_connect(GTK_OBJECT (window), "delete_event",
-                       (GtkSignalFunc) destroy_callback, NULL);
+    GLOBALS->window_ptranslate_c_5 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
+    install_focus_cb(GLOBALS->window_ptranslate_c_5, ((char *)&GLOBALS->window_ptranslate_c_5) - ((char *)GLOBALS));
+
+    gtk_window_set_title(GTK_WINDOW (GLOBALS->window_ptranslate_c_5), title);
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_ptranslate_c_5), "delete_event",(GtkSignalFunc) destroy_callback, NULL);
 
     tooltips=gtk_tooltips_new_2();
 
@@ -282,24 +274,20 @@ void ptrans_searchbox(char *title)
                         GTK_FILL | GTK_EXPAND,
                         GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
 
-    clist=gtk_clist_new_with_titles(1,titles);
-    gtk_clist_column_titles_passive(GTK_CLIST(clist)); 
+    GLOBALS->clist_ptranslate_c_2=gtk_clist_new_with_titles(1,titles);
+    gtk_clist_column_titles_passive(GTK_CLIST(GLOBALS->clist_ptranslate_c_2)); 
 
-    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_EXTENDED);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "select_row",
-			       GTK_SIGNAL_FUNC(select_row_callback),
-			       NULL);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "unselect_row",
-			       GTK_SIGNAL_FUNC(unselect_row_callback),
-			       NULL);
+    gtk_clist_set_selection_mode(GTK_CLIST(GLOBALS->clist_ptranslate_c_2), GTK_SELECTION_EXTENDED);
+    gtkwave_signal_connect_object (GTK_OBJECT (GLOBALS->clist_ptranslate_c_2), "select_row",GTK_SIGNAL_FUNC(select_row_callback),NULL);
+    gtkwave_signal_connect_object (GTK_OBJECT (GLOBALS->clist_ptranslate_c_2), "unselect_row",GTK_SIGNAL_FUNC(unselect_row_callback),NULL);
 
-    for(i=0;i<num_proc_filters;i++)
+    for(i=0;i<GLOBALS->num_proc_filters;i++)
 	{
-	gtk_clist_append(GTK_CLIST(clist),(gchar **)&(procsel_filter[i+1]));
+	gtk_clist_append(GTK_CLIST(GLOBALS->clist_ptranslate_c_2),(gchar **)&(GLOBALS->procsel_filter[i+1]));
 	}
-    gtk_clist_set_column_width(GTK_CLIST(clist),0,gtk_clist_optimal_column_width(GTK_CLIST(clist),0));
+    gtk_clist_set_column_width(GTK_CLIST(GLOBALS->clist_ptranslate_c_2),0,gtk_clist_optimal_column_width(GTK_CLIST(GLOBALS->clist_ptranslate_c_2),0));
 
-    gtk_widget_show (clist);
+    gtk_widget_show (GLOBALS->clist_ptranslate_c_2);
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
@@ -309,7 +297,7 @@ void ptrans_searchbox(char *title)
     gtk_widget_show(scrolled_win);
 
     /* gtk_scrolled_window_add_with_viewport doesn't seen to work right here.. */
-    gtk_container_add (GTK_CONTAINER (scrolled_win), clist);
+    gtk_container_add (GTK_CONTAINER (scrolled_win), GLOBALS->clist_ptranslate_c_2);
 
     gtk_container_add (GTK_CONTAINER (frame2), scrolled_win);
 
@@ -327,9 +315,7 @@ void ptrans_searchbox(char *title)
 
     button6 = gtk_button_new_with_label (" Add Proc Filter to List ");
     gtk_container_border_width (GTK_CONTAINER (button6), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button6), "clicked",
-			       GTK_SIGNAL_FUNC(add_filter_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button6), "clicked",GTK_SIGNAL_FUNC(add_filter_callback),GTK_OBJECT (GLOBALS->window_ptranslate_c_5));
     gtk_widget_show (button6);
     gtk_tooltips_set_tip_2(tooltips, button6, 
 		"Bring up a file requester to add a process filter to the filter select window.",NULL);
@@ -350,9 +336,7 @@ void ptrans_searchbox(char *title)
 
     button1 = gtk_button_new_with_label (" OK ");
     gtk_container_border_width (GTK_CONTAINER (button1), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button1), "clicked",
-			       GTK_SIGNAL_FUNC(ok_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button1), "clicked",GTK_SIGNAL_FUNC(ok_callback),GTK_OBJECT (GLOBALS->window_ptranslate_c_5));
     gtk_widget_show (button1);
     gtk_tooltips_set_tip_2(tooltips, button1, 
 		"Add selected signals to end of the display on the main window.",NULL);
@@ -361,19 +345,17 @@ void ptrans_searchbox(char *title)
 
     button5 = gtk_button_new_with_label (" Cancel ");
     gtk_container_border_width (GTK_CONTAINER (button5), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button5), "clicked",
-			       GTK_SIGNAL_FUNC(destroy_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button5), "clicked",GTK_SIGNAL_FUNC(destroy_callback),GTK_OBJECT (GLOBALS->window_ptranslate_c_5));
     gtk_tooltips_set_tip_2(tooltips, button5, 
 		"Do nothing and return to the main window.",NULL);
     gtk_widget_show (button5);
     gtk_box_pack_start (GTK_BOX (hbox), button5, TRUE, FALSE, 0);
 
     gtk_container_add (GTK_CONTAINER (frameh), hbox);
-    gtk_container_add (GTK_CONTAINER (window), table);
+    gtk_container_add (GTK_CONTAINER (GLOBALS->window_ptranslate_c_5), table);
 
-    gtk_widget_set_usize(GTK_WIDGET(window), 400, 400);
-    gtk_widget_show(window);
+    gtk_widget_set_usize(GTK_WIDGET(GLOBALS->window_ptranslate_c_5), 400, 400);
+    gtk_widget_show(GLOBALS->window_ptranslate_c_5);
 }
 
 
@@ -384,26 +366,26 @@ void set_current_translate_proc(char *name)
 {
 int i;
 
-for(i=1;i<num_proc_filters+1;i++)
+for(i=1;i<GLOBALS->num_proc_filters+1;i++)
 	{
-	if(!strcmp(procsel_filter[i], name)) { current_translate_proc = i; return; } 
+	if(!strcmp(GLOBALS->procsel_filter[i], name)) { GLOBALS->current_translate_proc = i; return; } 
 	}
 
-if(num_proc_filters < PROC_FILTER_MAX)
+if(GLOBALS->num_proc_filters < PROC_FILTER_MAX)
 	{
-	num_proc_filters++;
-	load_proc_filter(num_proc_filters, name);
-	if(!proc_filter[num_proc_filters])
+	GLOBALS->num_proc_filters++;
+	load_proc_filter(GLOBALS->num_proc_filters, name);
+	if(!GLOBALS->proc_filter[GLOBALS->num_proc_filters])
 		{
-		num_proc_filters--;
-		current_translate_proc = 0;
+		GLOBALS->num_proc_filters--;
+		GLOBALS->current_translate_proc = 0;
 		}
 		else
 		{
-		if(procsel_filter[num_proc_filters]) free_2(procsel_filter[num_proc_filters]);
-		procsel_filter[num_proc_filters] = malloc_2(strlen(name) + 1);
-		strcpy(procsel_filter[num_proc_filters], name);
-		current_translate_proc = num_proc_filters;
+		if(GLOBALS->procsel_filter[GLOBALS->num_proc_filters]) free_2(GLOBALS->procsel_filter[GLOBALS->num_proc_filters]);
+		GLOBALS->procsel_filter[GLOBALS->num_proc_filters] = malloc_2(strlen(name) + 1);
+		strcpy(GLOBALS->procsel_filter[GLOBALS->num_proc_filters], name);
+		GLOBALS->current_translate_proc = GLOBALS->num_proc_filters;
 		}
 	}
 }
@@ -411,8 +393,39 @@ if(num_proc_filters < PROC_FILTER_MAX)
 #endif
 
 /*
- * $Id: ptranslate.c,v 1.2 2007/04/20 02:08:13 gtkwave Exp $
+ * $Id: ptranslate.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
  * $Log: ptranslate.c,v $
+ * Revision 1.4  2007/09/12 17:26:45  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.3  2007/09/10 18:08:49  gtkwave
+ * tabs selection can swap dynamically based on external window focus
+ *
+ * Revision 1.2  2007/08/26 21:35:43  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.7  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.5  2007/08/06 03:50:48  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.4  2007/08/05 02:27:22  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
+ * Merge Complete - I hope
+ *
+ * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
+ * Merged in the main line
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:30  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:13  gtkwave
  * initial release
  *
