@@ -8,6 +8,7 @@
  */
 
 #include <config.h>
+#include "globals.h"
 #include <gtk/gtk.h>
 #include "gtk12compat.h"
 #include "symbol.h"
@@ -21,7 +22,6 @@
 
 /************************ splay ************************/
 
-
 xl_Tree * xl_splay (char *i, xl_Tree * t) {
 /* Simple top down splay, not requiring i to be in the tree t.  */
 /* What it does is described above.                             */
@@ -70,7 +70,7 @@ xl_Tree * xl_splay (char *i, xl_Tree * t) {
 }
 
 
-static xl_Tree * xl_insert(char *i, xl_Tree * t, char *trans) {
+xl_Tree * xl_insert(char *i, xl_Tree * t, char *trans) {
 /* Insert i into the tree t, unless it's already there.    */
 /* Return a pointer to the resulting tree.                 */
     xl_Tree * n;
@@ -82,7 +82,7 @@ static xl_Tree * xl_insert(char *i, xl_Tree * t, char *trans) {
 	exit(255);
     }
     n->item = strcpy(malloc_2(strlen(i)+1), i);
-    n->trans = strcpy(malloc_2(strlen(trans)+1), trans);
+    if(trans) n->trans = strcpy(malloc_2(strlen(trans)+1), trans);
 
     if (t == NULL) {
 	n->left = n->right = NULL;
@@ -102,38 +102,58 @@ static xl_Tree * xl_insert(char *i, xl_Tree * t, char *trans) {
 	return n;
     } else { /* We get here if it's already in the tree */
              /* Don't add it again                      */
-	free_2(n->trans);
+	if(n->trans) free_2(n->trans);
 	free_2(n->item);
 	free_2(n);
 	return t;
     }
 }
 
+xl_Tree * xl_delete(char *i, xl_Tree * t) {
+/* Deletes i from the tree if it's there.               */
+/* Return a pointer to the resulting tree.              */
+    xl_Tree * x;
+    if (t==NULL) return NULL;
+    t = xl_splay(i,t);
+    if (strcmp(i, t->item) == 0) {               /* found it */
+        if (t->left == NULL) {
+            x = t->right;
+        } else {
+            x = xl_splay(i, t->left);
+            x->right = t->right;
+        }
+        if(t->trans) free_2(t->trans);
+        free_2(t->item);
+        free_2(t);
+        return x;
+    }
+    return t;                         /* It wasn't there */
+}
+
+
 /************************ splay ************************/
 
-int current_translate_file = 0;	/* for the viewer */
-static int current_filter = 0; 	/* in requester */
-int num_file_filters = 0;
-char *filesel_filter[FILE_FILTER_MAX+1];
-xl_Tree *xl_file_filter[FILE_FILTER_MAX+1];
 
 void init_filetrans_data(void)
 {
 int i;
 
+if(!GLOBALS->filesel_filter) { GLOBALS->filesel_filter = calloc_2(FILE_FILTER_MAX+1, sizeof(char *)); }
+if(!GLOBALS->xl_file_filter) { GLOBALS->xl_file_filter = calloc_2(FILE_FILTER_MAX+1, sizeof(struct xl_tree_node *)); }
+
 for(i=0;i<FILE_FILTER_MAX+1;i++)
 	{
-	filesel_filter[i] = NULL;
-	xl_file_filter[i] = NULL;
+	GLOBALS->filesel_filter[i] = NULL;
+	GLOBALS->xl_file_filter[i] = NULL;
 	}
 }
 
 static void regen_display(void)
 {
-signalwindow_width_dirty=1;
+GLOBALS->signalwindow_width_dirty=1;
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
@@ -148,10 +168,10 @@ free_2(t);
 
 void remove_file_filter(int which, int regen)
 {
-if(xl_file_filter[which])
+if(GLOBALS->xl_file_filter[which])
 	{
-	remove_file_filter_2(xl_file_filter[which]);
-	xl_file_filter[which] = NULL;
+	remove_file_filter_2(GLOBALS->xl_file_filter[which]);
+	GLOBALS->xl_file_filter[which] = NULL;
 	}
 
 if(regen)
@@ -194,7 +214,7 @@ while(!feof(f))
 					while(*xlt && isspace(*xlt)) xlt++;
 					if(*xlt)
 						{
-						xl_file_filter[which] =  xl_insert(lhs, xl_file_filter[which], xlt);
+						GLOBALS->xl_file_filter[which] =  xl_insert(lhs, GLOBALS->xl_file_filter[which], xlt);
 						}
 					}
 				}
@@ -211,9 +231,9 @@ void install_file_filter(int which)
 {
 int found = 0;
 
-if(traces.first)  
+if(GLOBALS->traces.first)  
         {
-        Trptr t = traces.first;
+        Trptr t = GLOBALS->traces.first;
         while(t)
                 {
                 if(t->flags&TR_HIGHLIGHT)
@@ -245,35 +265,31 @@ if(found)
 
 /************************************************************************/
 
-static int is_active=0;
-static char *fcurr = NULL;
 
-static GtkWidget *window;
-static GtkWidget *clist;
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-is_active=0;
-gtk_widget_destroy(window);
-window = NULL;
+GLOBALS->is_active_translate_c_5=0;
+gtk_widget_destroy(GLOBALS->window_translate_c_11);
+GLOBALS->window_translate_c_11 = NULL;
 }
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-install_file_filter(current_filter);
+install_file_filter(GLOBALS->current_filter_translate_c_2);
 destroy_callback(widget, nothing);
 }
 
 static void select_row_callback(GtkWidget *widget, gint row, gint column,
 	GdkEventButton *event, gpointer data)
 {
-current_filter = row + 1;
+GLOBALS->current_filter_translate_c_2 = row + 1;
 }
 
 static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
 	GdkEventButton *event, gpointer data)
 {
-current_filter = 0; /* none */
+GLOBALS->current_filter_translate_c_2 = 0; /* none */
 }
 
 
@@ -282,15 +298,15 @@ static void add_filter_callback_2(GtkWidget *widget, GtkWidget *nothing)
 int i;
 GtkCList *cl;
 
-if(!filesel_ok) { return; }
+if(!GLOBALS->filesel_ok) { return; }
 
-if(*fileselbox_text)
+if(*GLOBALS->fileselbox_text)
 	{
-	for(i=0;i<num_file_filters;i++)
+	for(i=0;i<GLOBALS->num_file_filters;i++)
 		{
-		if(filesel_filter[i])
+		if(GLOBALS->filesel_filter[i])
 			{
-			if(!strcmp(filesel_filter[i], *fileselbox_text)) 
+			if(!strcmp(GLOBALS->filesel_filter[i], *GLOBALS->fileselbox_text)) 
 				{
 				status_text("Filter already imported.\n");
 				return;
@@ -299,36 +315,36 @@ if(*fileselbox_text)
 		}
 	}
 
-num_file_filters++;
-load_file_filter(num_file_filters, *fileselbox_text);
-if(xl_file_filter[num_file_filters])
+GLOBALS->num_file_filters++;
+load_file_filter(GLOBALS->num_file_filters, *GLOBALS->fileselbox_text);
+if(GLOBALS->xl_file_filter[GLOBALS->num_file_filters])
 	{
-	if(filesel_filter[num_file_filters]) free_2(filesel_filter[num_file_filters]);
-	filesel_filter[num_file_filters] = malloc_2(strlen(*fileselbox_text) + 1);
-	strcpy(filesel_filter[num_file_filters], *fileselbox_text);
+	if(GLOBALS->filesel_filter[GLOBALS->num_file_filters]) free_2(GLOBALS->filesel_filter[GLOBALS->num_file_filters]);
+	GLOBALS->filesel_filter[GLOBALS->num_file_filters] = malloc_2(strlen(*GLOBALS->fileselbox_text) + 1);
+	strcpy(GLOBALS->filesel_filter[GLOBALS->num_file_filters], *GLOBALS->fileselbox_text);
 
-	cl=GTK_CLIST(clist);
+	cl=GTK_CLIST(GLOBALS->clist_translate_c_4);
 	gtk_clist_freeze(cl);
-	gtk_clist_append(cl,(gchar **)&(filesel_filter[num_file_filters]));
+	gtk_clist_append(cl,(gchar **)&(GLOBALS->filesel_filter[GLOBALS->num_file_filters]));
 
 	gtk_clist_set_column_width(cl,0,gtk_clist_optimal_column_width(cl,0));
 	gtk_clist_thaw(cl);
 	}
 	else
 	{
-	num_file_filters--;
+	GLOBALS->num_file_filters--;
 	}
 }
 
 static void add_filter_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-if(num_file_filters == FILE_FILTER_MAX)
+if(GLOBALS->num_file_filters == FILE_FILTER_MAX)
 	{
 	status_text("Max number of file filters installed already.\n");
 	return;
 	}
 
-fileselbox("Select Filter File",&fcurr,GTK_SIGNAL_FUNC(add_filter_callback_2), GTK_SIGNAL_FUNC(NULL),NULL, 0);
+fileselbox("Select Filter File",&GLOBALS->fcurr_translate_c_2,GTK_SIGNAL_FUNC(add_filter_callback_2), GTK_SIGNAL_FUNC(NULL),NULL, 0);
 }
 
 /*
@@ -346,20 +362,21 @@ void trans_searchbox(char *title)
     GtkWidget *table;
     GtkTooltips *tooltips;
 
-    if(is_active) 
+    if(GLOBALS->is_active_translate_c_5) 
 	{
-	gdk_window_raise(window->window);
+	gdk_window_raise(GLOBALS->window_translate_c_11->window);
 	return;
 	}
 
-    is_active=1;
-    current_filter = 0;
+    GLOBALS->is_active_translate_c_5=1;
+    GLOBALS->current_filter_translate_c_2 = 0;
 
     /* create a new modal window */
-    window = gtk_window_new(disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW (window), title);
-    gtk_signal_connect(GTK_OBJECT (window), "delete_event",
-                       (GtkSignalFunc) destroy_callback, NULL);
+    GLOBALS->window_translate_c_11 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
+    install_focus_cb(GLOBALS->window_translate_c_11, ((char *)&GLOBALS->window_translate_c_11) - ((char *)GLOBALS));
+
+    gtk_window_set_title(GTK_WINDOW (GLOBALS->window_translate_c_11), title);
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_translate_c_11), "delete_event",(GtkSignalFunc) destroy_callback, NULL);
 
     tooltips=gtk_tooltips_new_2();
 
@@ -379,24 +396,20 @@ void trans_searchbox(char *title)
                         GTK_FILL | GTK_EXPAND,
                         GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
 
-    clist=gtk_clist_new_with_titles(1,titles);
-    gtk_clist_column_titles_passive(GTK_CLIST(clist)); 
+    GLOBALS->clist_translate_c_4=gtk_clist_new_with_titles(1,titles);
+    gtk_clist_column_titles_passive(GTK_CLIST(GLOBALS->clist_translate_c_4)); 
 
-    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_EXTENDED);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "select_row",
-			       GTK_SIGNAL_FUNC(select_row_callback),
-			       NULL);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "unselect_row",
-			       GTK_SIGNAL_FUNC(unselect_row_callback),
-			       NULL);
+    gtk_clist_set_selection_mode(GTK_CLIST(GLOBALS->clist_translate_c_4), GTK_SELECTION_EXTENDED);
+    gtkwave_signal_connect_object (GTK_OBJECT (GLOBALS->clist_translate_c_4), "select_row",GTK_SIGNAL_FUNC(select_row_callback),NULL);
+    gtkwave_signal_connect_object (GTK_OBJECT (GLOBALS->clist_translate_c_4), "unselect_row",GTK_SIGNAL_FUNC(unselect_row_callback),NULL);
 
-    for(i=0;i<num_file_filters;i++)
+    for(i=0;i<GLOBALS->num_file_filters;i++)
 	{
-	gtk_clist_append(GTK_CLIST(clist),(gchar **)&(filesel_filter[i+1]));
+	gtk_clist_append(GTK_CLIST(GLOBALS->clist_translate_c_4),(gchar **)&(GLOBALS->filesel_filter[i+1]));
 	}
-    gtk_clist_set_column_width(GTK_CLIST(clist),0,gtk_clist_optimal_column_width(GTK_CLIST(clist),0));
+    gtk_clist_set_column_width(GTK_CLIST(GLOBALS->clist_translate_c_4),0,gtk_clist_optimal_column_width(GTK_CLIST(GLOBALS->clist_translate_c_4),0));
 
-    gtk_widget_show (clist);
+    gtk_widget_show (GLOBALS->clist_translate_c_4);
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
@@ -406,7 +419,7 @@ void trans_searchbox(char *title)
     gtk_widget_show(scrolled_win);
 
     /* gtk_scrolled_window_add_with_viewport doesn't seen to work right here.. */
-    gtk_container_add (GTK_CONTAINER (scrolled_win), clist);
+    gtk_container_add (GTK_CONTAINER (scrolled_win), GLOBALS->clist_translate_c_4);
 
     gtk_container_add (GTK_CONTAINER (frame2), scrolled_win);
 
@@ -424,9 +437,7 @@ void trans_searchbox(char *title)
 
     button6 = gtk_button_new_with_label (" Add Filter to List ");
     gtk_container_border_width (GTK_CONTAINER (button6), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button6), "clicked",
-			       GTK_SIGNAL_FUNC(add_filter_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button6), "clicked",GTK_SIGNAL_FUNC(add_filter_callback),GTK_OBJECT (GLOBALS->window_translate_c_11));
     gtk_widget_show (button6);
     gtk_tooltips_set_tip_2(tooltips, button6, 
 		"Bring up a file requester to add a filter to the filter select window.",NULL);
@@ -447,9 +458,7 @@ void trans_searchbox(char *title)
 
     button1 = gtk_button_new_with_label (" OK ");
     gtk_container_border_width (GTK_CONTAINER (button1), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button1), "clicked",
-			       GTK_SIGNAL_FUNC(ok_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button1), "clicked",GTK_SIGNAL_FUNC(ok_callback),GTK_OBJECT (GLOBALS->window_translate_c_11));
     gtk_widget_show (button1);
     gtk_tooltips_set_tip_2(tooltips, button1, 
 		"Add selected signals to end of the display on the main window.",NULL);
@@ -458,19 +467,17 @@ void trans_searchbox(char *title)
 
     button5 = gtk_button_new_with_label (" Cancel ");
     gtk_container_border_width (GTK_CONTAINER (button5), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button5), "clicked",
-			       GTK_SIGNAL_FUNC(destroy_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button5), "clicked",GTK_SIGNAL_FUNC(destroy_callback),GTK_OBJECT (GLOBALS->window_translate_c_11));
     gtk_tooltips_set_tip_2(tooltips, button5, 
 		"Do nothing and return to the main window.",NULL);
     gtk_widget_show (button5);
     gtk_box_pack_start (GTK_BOX (hbox), button5, TRUE, FALSE, 0);
 
     gtk_container_add (GTK_CONTAINER (frameh), hbox);
-    gtk_container_add (GTK_CONTAINER (window), table);
+    gtk_container_add (GTK_CONTAINER (GLOBALS->window_translate_c_11), table);
 
-    gtk_widget_set_usize(GTK_WIDGET(window), 400, 400);
-    gtk_widget_show(window);
+    gtk_widget_set_usize(GTK_WIDGET(GLOBALS->window_translate_c_11), 400, 400);
+    gtk_widget_show(GLOBALS->window_translate_c_11);
 }
 
 
@@ -481,33 +488,67 @@ void set_current_translate_file(char *name)
 {
 int i;
 
-for(i=1;i<num_file_filters+1;i++)
+for(i=1;i<GLOBALS->num_file_filters+1;i++)
 	{
-	if(!strcmp(filesel_filter[i], name)) { current_translate_file = i; return; } 
+	if(!strcmp(GLOBALS->filesel_filter[i], name)) { GLOBALS->current_translate_file = i; return; } 
 	}
 
-if(num_file_filters < FILE_FILTER_MAX)
+if(GLOBALS->num_file_filters < FILE_FILTER_MAX)
 	{
-	num_file_filters++;
-	load_file_filter(num_file_filters, name);
-	if(!xl_file_filter[num_file_filters])
+	GLOBALS->num_file_filters++;
+	load_file_filter(GLOBALS->num_file_filters, name);
+	if(!GLOBALS->xl_file_filter[GLOBALS->num_file_filters])
 		{
-		num_file_filters--;
-		current_translate_file = 0;
+		GLOBALS->num_file_filters--;
+		GLOBALS->current_translate_file = 0;
 		}
 		else
 		{
-		if(filesel_filter[num_file_filters]) free_2(filesel_filter[num_file_filters]);
-		filesel_filter[num_file_filters] = malloc_2(strlen(name) + 1);
-		strcpy(filesel_filter[num_file_filters], name);
-		current_translate_file = num_file_filters;
+		if(GLOBALS->filesel_filter[GLOBALS->num_file_filters]) free_2(GLOBALS->filesel_filter[GLOBALS->num_file_filters]);
+		GLOBALS->filesel_filter[GLOBALS->num_file_filters] = malloc_2(strlen(name) + 1);
+		strcpy(GLOBALS->filesel_filter[GLOBALS->num_file_filters], name);
+		GLOBALS->current_translate_file = GLOBALS->num_file_filters;
 		}
 	}
 }
 
 /*
- * $Id: translate.c,v 1.2 2007/04/20 02:08:17 gtkwave Exp $
+ * $Id: translate.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
  * $Log: translate.c,v $
+ * Revision 1.4  2007/09/12 17:26:45  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.3  2007/09/10 18:08:49  gtkwave
+ * tabs selection can swap dynamically based on external window focus
+ *
+ * Revision 1.2  2007/08/26 21:35:46  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.8  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.7  2007/08/21 22:35:40  gtkwave
+ * prelim tree state merge
+ *
+ * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.5  2007/08/06 03:50:49  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.4  2007/08/05 02:27:24  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
+ * Merge Complete - I hope
+ *
+ * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
+ * Merged in the main line
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:24  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:17  gtkwave
  * initial release
  *
