@@ -23,26 +23,14 @@ void dnd_setup(GtkWidget *w)
 }
 
 
-char autoname_bundles=0;
-
-static GtkWidget *window1;
-static GtkWidget *entry_a;
-static char *entrybox_text_local=NULL;
-static GtkSignalFunc cleanup_e;
-static struct tree *selectedtree=NULL;
-
-
-static int is_active=0;
-GtkCTree *ctree_main=NULL;
-
 static void select_row_callback(GtkWidget *widget, gint row, gint column,
         GdkEventButton *event, gpointer data)
 {
 struct tree *t;
 
-t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(ctree_main), row);
+t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->ctree_main), row);
 DEBUG(printf("TS: %08x %s\n",t,t->name));
-selectedtree=t;
+GLOBALS->selectedtree_treesearch_gtk1_c=t;
 }
 
 static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
@@ -50,40 +38,40 @@ static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
 {
 struct tree *t;
 
-t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(ctree_main), row);
+t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->ctree_main), row);
 DEBUG(printf("TU: %08x %s\n",t,t->name));
-selectedtree=NULL;
+GLOBALS->selectedtree_treesearch_gtk1_c=NULL;
 }
 
 
-
-
 int treebox_is_active(void)
 {
-return(is_active);
+return(GLOBALS->is_active_treesearch_gtk1_c);
 }
 
 static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
   G_CONST_RETURN gchar *entry_text;
   int len;
-  entry_text = gtk_entry_get_text(GTK_ENTRY(entry_a));
+  entry_text = gtk_entry_get_text(GTK_ENTRY(GLOBALS->entry_a_treesearch_gtk1_c));
   DEBUG(printf("Entry contents: %s\n", entry_text));
-  if(!(len=strlen(entry_text))) entrybox_text_local=NULL;
-	else strcpy((entrybox_text_local=(char *)malloc_2(len+1)),entry_text);
+  if(!(len=strlen(entry_text))) GLOBALS->entrybox_text_local_treesearch_gtk1_c=NULL;
+	else strcpy((GLOBALS->entrybox_text_local_treesearch_gtk1_c=(char *)malloc_2(len+1)),entry_text);
 
-  gtk_grab_remove(window1);
-  gtk_widget_destroy(window1);
+  gtk_grab_remove(GLOBALS->window1_treesearch_gtk1_c);
+  gtk_widget_destroy(GLOBALS->window1_treesearch_gtk1_c);
+  GLOBALS->window1_treesearch_gtk1_c = NULL;
 
-  cleanup_e();
+  GLOBALS->cleanup_e_treesearch_gtk1_c();
 }
 
 static void destroy_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
   DEBUG(printf("Entry Cancel\n"));
-  entrybox_text_local=NULL;
-  gtk_grab_remove(window1);
-  gtk_widget_destroy(window1);
+  GLOBALS->entrybox_text_local_treesearch_gtk1_c=NULL;
+  gtk_grab_remove(GLOBALS->window1_treesearch_gtk1_c);
+  gtk_widget_destroy(GLOBALS->window1_treesearch_gtk1_c);
+  GLOBALS->window1_treesearch_gtk1_c = NULL;
 }
 
 static void entrybox_local(char *title, int width, char *default_text, int maxch, GtkSignalFunc func)
@@ -91,29 +79,28 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
     GtkWidget *vbox, *hbox;
     GtkWidget *button1, *button2;
 
-    cleanup_e=func;
+    GLOBALS->cleanup_e_treesearch_gtk1_c=func;
 
     /* create a new modal window */
-    window1 = gtk_window_new(disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    gtk_grab_add(window1);
-    gtk_widget_set_usize( GTK_WIDGET (window1), width, 60);
-    gtk_window_set_title(GTK_WINDOW (window1), title);
-    gtk_signal_connect(GTK_OBJECT (window1), "delete_event",
-                       (GtkSignalFunc) destroy_callback_e, NULL);
+    GLOBALS->window1_treesearch_gtk1_c = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
+    install_focus_cb(GLOBALS->window1_treesearch_gtk1_c, ((char *)&GLOBALS->window1_treesearch_gtk1_c) - ((char *)GLOBALS));
+
+    gtk_grab_add(GLOBALS->window1_treesearch_gtk1_c);
+    gtk_widget_set_usize( GTK_WIDGET (GLOBALS->window1_treesearch_gtk1_c), width, 60);
+    gtk_window_set_title(GTK_WINDOW (GLOBALS->window1_treesearch_gtk1_c), title);
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window1_treesearch_gtk1_c), "delete_event", (GtkSignalFunc) destroy_callback_e, NULL);
 
     vbox = gtk_vbox_new (FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (window1), vbox);
+    gtk_container_add (GTK_CONTAINER (GLOBALS->window1_treesearch_gtk1_c), vbox);
     gtk_widget_show (vbox);
 
-    entry_a = gtk_entry_new_with_max_length (maxch);
-    gtk_signal_connect(GTK_OBJECT(entry_a), "activate",
-		       GTK_SIGNAL_FUNC(enter_callback_e),
-		       entry_a);
-    gtk_entry_set_text (GTK_ENTRY (entry_a), default_text);
-    gtk_entry_select_region (GTK_ENTRY (entry_a),
-			     0, GTK_ENTRY(entry_a)->text_length);
-    gtk_box_pack_start (GTK_BOX (vbox), entry_a, TRUE, TRUE, 0);
-    gtk_widget_show (entry_a);
+    GLOBALS->entry_a_treesearch_gtk1_c = gtk_entry_new_with_max_length (maxch);
+    gtkwave_signal_connect(GTK_OBJECT(GLOBALS->entry_a_treesearch_gtk1_c), "activate", GTK_SIGNAL_FUNC(enter_callback_e), GLOBALS->entry_a_treesearch_gtk1_c);
+    gtk_entry_set_text (GTK_ENTRY (GLOBALS->entry_a_treesearch_gtk1_c), default_text);
+    gtk_entry_select_region (GTK_ENTRY (GLOBALS->entry_a_treesearch_gtk1_c),
+			     0, GTK_ENTRY(GLOBALS->entry_a_treesearch_gtk1_c)->text_length);
+    gtk_box_pack_start (GTK_BOX (vbox), GLOBALS->entry_a_treesearch_gtk1_c, TRUE, TRUE, 0);
+    gtk_widget_show (GLOBALS->entry_a_treesearch_gtk1_c);
 
     hbox = gtk_hbox_new (FALSE, 1);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
@@ -121,37 +108,24 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
 
     button1 = gtk_button_new_with_label ("OK");
     gtk_widget_set_usize(button1, 100, -1);
-    gtk_signal_connect(GTK_OBJECT (button1), "clicked",
-			       GTK_SIGNAL_FUNC(enter_callback_e),
-			       NULL);
+    gtkwave_signal_connect(GTK_OBJECT (button1), "clicked", GTK_SIGNAL_FUNC(enter_callback_e), NULL);
     gtk_widget_show (button1);
     gtk_container_add (GTK_CONTAINER (hbox), button1);
     GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-    gtk_signal_connect_object (GTK_OBJECT (button1),
-                                "realize",
-                             (GtkSignalFunc) gtk_widget_grab_default,
-                             GTK_OBJECT (button1));
+    gtkwave_signal_connect_object (GTK_OBJECT (button1), "realize", (GtkSignalFunc) gtk_widget_grab_default, GTK_OBJECT (button1));
 
     button2 = gtk_button_new_with_label ("Cancel");
     gtk_widget_set_usize(button2, 100, -1);
-    gtk_signal_connect(GTK_OBJECT (button2), "clicked",
-			       GTK_SIGNAL_FUNC(destroy_callback_e),
-			       NULL);
+    gtkwave_signal_connect(GTK_OBJECT (button2), "clicked", GTK_SIGNAL_FUNC(destroy_callback_e), NULL);
     GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);
     gtk_widget_show (button2);
     gtk_container_add (GTK_CONTAINER (hbox), button2);
 
-    gtk_widget_show(window1);
+    gtk_widget_show(GLOBALS->window1_treesearch_gtk1_c);
 }
 
 /***************************************************************************/
 
-static GtkWidget *window;
-static GtkWidget *tree;
-static char bundle_direction=0;
-static GtkSignalFunc cleanup;
-
-
 struct tree *fetchhigh(struct tree *t)
 {
 while(t->child) t=t->child;
@@ -215,18 +189,18 @@ if(t)
 static void
 bundle_cleanup(GtkWidget *widget, gpointer data)
 { 
-if(entrybox_text_local) 
+if(GLOBALS->entrybox_text_local_treesearch_gtk1_c) 
         {
         char *efix;
  
-	if(!strlen(entrybox_text_local))
+	if(!strlen(GLOBALS->entrybox_text_local_treesearch_gtk1_c))
 		{
 	        DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
-		fetchvex(selectedtree, bundle_direction);
+		fetchvex(GLOBALS->selectedtree_treesearch_gtk1_c, GLOBALS->bundle_direction_treesearch_gtk1_c);
 		}
 		else
 		{
-	        efix=entrybox_text_local;
+	        efix=GLOBALS->entrybox_text_local_treesearch_gtk1_c;
 	        while(*efix)
 	                {
 	                if(*efix==' ')
@@ -236,37 +210,37 @@ if(entrybox_text_local)
 	                efix++;
 	                }
 	 
-	        DEBUG(printf("Bundle name is: %s\n",entrybox_text_local));
-	        add_vector_range(entrybox_text_local, 
-				fetchlow(selectedtree)->which,
-				fetchhigh(selectedtree)->which, 
-				bundle_direction);
+	        DEBUG(printf("Bundle name is: %s\n",GLOBALS->entrybox_text_local_treesearch_gtk1_c));
+	        add_vector_range(GLOBALS->entrybox_text_local_treesearch_gtk1_c, 
+				fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which,
+				fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which, 
+				GLOBALS->bundle_direction_treesearch_gtk1_c);
 		}
-        free_2(entrybox_text_local);
+        free_2(GLOBALS->entrybox_text_local_treesearch_gtk1_c);
         }
 	else
 	{
         DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
-	fetchvex(selectedtree, bundle_direction);
+	fetchvex(GLOBALS->selectedtree_treesearch_gtk1_c, GLOBALS->bundle_direction_treesearch_gtk1_c);
 	}
 
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
  
 static void
 bundle_callback_generic(void)
 {
-if(selectedtree)
+if(GLOBALS->selectedtree_treesearch_gtk1_c)
 	{
-	if(!autoname_bundles)
+	if(!GLOBALS->autoname_bundles)
 	        {
 	        entrybox_local("Enter Bundle Name",300,"",128,GTK_SIGNAL_FUNC(bundle_cleanup));
 	        }
 	        else
 	        {
-	        entrybox_text_local=NULL;
+	        GLOBALS->entrybox_text_local_treesearch_gtk1_c=NULL;
 	        bundle_cleanup(NULL, NULL);
 	        }
 	}
@@ -275,14 +249,14 @@ if(selectedtree)
 static void
 bundle_callback_up(GtkWidget *widget, gpointer data)
 {
-bundle_direction=0;
+GLOBALS->bundle_direction_treesearch_gtk1_c=0;
 bundle_callback_generic();
 }
 
 static void
 bundle_callback_down(GtkWidget *widget, gpointer data)
 {
-bundle_direction=1;
+GLOBALS->bundle_direction_treesearch_gtk1_c=1;
 bundle_callback_generic();
 }
 
@@ -291,41 +265,41 @@ static void insert_callback(GtkWidget *widget, GtkWidget *nothing)
 Traces tcache;
 int i;
 
-if(!selectedtree) return;
+if(!GLOBALS->selectedtree_treesearch_gtk1_c) return;
 
-memcpy(&tcache,&traces,sizeof(Traces));
-traces.total=0;
-traces.first=traces.last=NULL;
+memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
+GLOBALS->traces.total=0;
+GLOBALS->traces.first=GLOBALS->traces.last=NULL;
 
 set_window_busy(widget);
 
-for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
         {
         struct symbol *s;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=autocoalesce;
+		s->vec_root->selected=GLOBALS->autocoalesce;
 		}
         }
 
 /* LX2 */
-if(is_lx2)
+if(GLOBALS->is_lx2)
         {
         int pre_import = 0;
 
-        for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+        for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
                 {
                 struct symbol *s, *t;
-                s=facs[i];
+                s=GLOBALS->facs[i];
                 t=s->vec_root;
-                if((t)&&(autocoalesce))
+                if((t)&&(GLOBALS->autocoalesce))
                         {
                         if(t->selected)
                                 {
                                 while(t)
                                         {
-                                        if(t->n->mvlfac)
+                                        if(t->n->mv.mvlfac)
                                                 {
                                                 lx2_set_fac_process_mask(t->n);
                                                 pre_import++;
@@ -336,7 +310,7 @@ if(is_lx2)
                         }
                         else
                         {
-                        if(s->n->mvlfac)
+                        if(s->n->mv.mvlfac)
                                 {
                                 lx2_set_fac_process_mask(s->n);
                                 pre_import++;
@@ -351,13 +325,13 @@ if(is_lx2)
         }
 /* LX2 */
 
-for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
         {
 	int len;
         struct symbol *s, *t;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	t=s->vec_root;
-	if((t)&&(autocoalesce))
+	if((t)&&(GLOBALS->autocoalesce))
 		{
 		if(t->selected)
 			{
@@ -373,28 +347,28 @@ for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
 		}
 		else
 		{
-	        AddNode(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);  
 		}
         }
 
 set_window_idle(widget);
 
-traces.buffercount=traces.total;
-traces.buffer=traces.first;
-traces.bufferlast=traces.last;
-traces.first=tcache.first;
-traces.last=tcache.last;
-traces.total=tcache.total;
+GLOBALS->traces.buffercount=GLOBALS->traces.total;
+GLOBALS->traces.buffer=GLOBALS->traces.first;
+GLOBALS->traces.bufferlast=GLOBALS->traces.last;
+GLOBALS->traces.first=tcache.first;
+GLOBALS->traces.last=tcache.last;
+GLOBALS->traces.total=tcache.total;
 
 PasteBuffer();
 
-traces.buffercount=tcache.buffercount;
-traces.buffer=tcache.buffer;
-traces.bufferlast=tcache.bufferlast;
+GLOBALS->traces.buffercount=tcache.buffercount;
+GLOBALS->traces.buffer=tcache.buffer;
+GLOBALS->traces.bufferlast=tcache.bufferlast;
 
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 static void replace_callback(GtkWidget *widget, GtkWidget *nothing)
@@ -403,41 +377,41 @@ Traces tcache;
 int i;
 Trptr tfirst=NULL, tlast=NULL;
 
-if(!selectedtree) return;
+if(!GLOBALS->selectedtree_treesearch_gtk1_c) return;
 
-memcpy(&tcache,&traces,sizeof(Traces));
-traces.total=0;
-traces.first=traces.last=NULL;
+memcpy(&tcache,&GLOBALS->traces,sizeof(Traces));
+GLOBALS->traces.total=0;
+GLOBALS->traces.first=GLOBALS->traces.last=NULL;
 
 set_window_busy(widget);
 
-for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
         {
         struct symbol *s;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=autocoalesce;
+		s->vec_root->selected=GLOBALS->autocoalesce;
 		}
         }
 
 /* LX2 */
-if(is_lx2)
+if(GLOBALS->is_lx2)
         {
         int pre_import = 0;
 
-        for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+        for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
                 {
                 struct symbol *s, *t;
-                s=facs[i];
+                s=GLOBALS->facs[i];
                 t=s->vec_root;
-                if((t)&&(autocoalesce))
+                if((t)&&(GLOBALS->autocoalesce))
                         {
                         if(t->selected)
                                 {
                                 while(t)
                                         {
-                                        if(t->n->mvlfac)
+                                        if(t->n->mv.mvlfac)
                                                 {
                                                 lx2_set_fac_process_mask(t->n);
                                                 pre_import++;
@@ -448,7 +422,7 @@ if(is_lx2)
                         }
                         else
                         {
-                        if(s->n->mvlfac)
+                        if(s->n->mv.mvlfac)
                                 {
                                 lx2_set_fac_process_mask(s->n);
                                 pre_import++;
@@ -463,13 +437,13 @@ if(is_lx2)
         }
 /* LX2 */
 
-for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
         {
 	int len;
         struct symbol *s, *t;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	t=s->vec_root;
-	if((t)&&(autocoalesce))
+	if((t)&&(GLOBALS->autocoalesce))
 		{
 		if(t->selected)
 			{
@@ -485,26 +459,26 @@ for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
 		}
 		else
 		{
-	        AddNode(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);  
 		}
         }
 
 set_window_idle(widget);
 
-tfirst=traces.first; tlast=traces.last;	/* cache for highlighting */
+tfirst=GLOBALS->traces.first; tlast=GLOBALS->traces.last;	/* cache for highlighting */
 
-traces.buffercount=traces.total;
-traces.buffer=traces.first;
-traces.bufferlast=traces.last;
-traces.first=tcache.first;
-traces.last=tcache.last;
-traces.total=tcache.total;
+GLOBALS->traces.buffercount=GLOBALS->traces.total;
+GLOBALS->traces.buffer=GLOBALS->traces.first;
+GLOBALS->traces.bufferlast=GLOBALS->traces.last;
+GLOBALS->traces.first=tcache.first;
+GLOBALS->traces.last=tcache.last;
+GLOBALS->traces.total=tcache.total;
 
 PasteBuffer();
 
-traces.buffercount=tcache.buffercount;
-traces.buffer=tcache.buffer;
-traces.bufferlast=tcache.bufferlast;
+GLOBALS->traces.buffercount=tcache.buffercount;
+GLOBALS->traces.buffer=tcache.buffer;
+GLOBALS->traces.bufferlast=tcache.bufferlast;
 
 CutBuffer();
 
@@ -516,45 +490,45 @@ while(tfirst)
 	}
 
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
 int i;
 
-if(!selectedtree) return;
+if(!GLOBALS->selectedtree_treesearch_gtk1_c) return;
 
 set_window_busy(widget);
 
-for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
         {
         struct symbol *s;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=autocoalesce;
+		s->vec_root->selected=GLOBALS->autocoalesce;
 		}
         }
 
 /* LX2 */
-if(is_lx2)
+if(GLOBALS->is_lx2)
         {
         int pre_import = 0;
 
-        for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+        for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
                 {
                 struct symbol *s, *t;
-                s=facs[i];
+                s=GLOBALS->facs[i];
                 t=s->vec_root;
-                if((t)&&(autocoalesce))
+                if((t)&&(GLOBALS->autocoalesce))
                         {
                         if(t->selected)
                                 {
                                 while(t)
                                         {
-                                        if(t->n->mvlfac)
+                                        if(t->n->mv.mvlfac)
                                                 {
                                                 lx2_set_fac_process_mask(t->n);
                                                 pre_import++;
@@ -565,7 +539,7 @@ if(is_lx2)
                         }
                         else
                         {
-                        if(s->n->mvlfac)
+                        if(s->n->mv.mvlfac)
                                 {
                                 lx2_set_fac_process_mask(s->n);
                                 pre_import++;
@@ -580,13 +554,13 @@ if(is_lx2)
         }
 /* LX2 */
 
-for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
+for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i++)
         {
 	int len;
         struct symbol *s, *t;  
-        s=facs[i];
+        s=GLOBALS->facs[i];
 	t=s->vec_root;
-	if((t)&&(autocoalesce))
+	if((t)&&(GLOBALS->autocoalesce))
 		{
 		if(t->selected)
 			{
@@ -602,22 +576,23 @@ for(i=fetchlow(selectedtree)->which;i<=fetchhigh(selectedtree)->which;i++)
 		}
 		else
 		{
-	        AddNode(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);  
 		}
         }
 
 set_window_idle(widget);
 
 MaxSignalLength();
-signalarea_configure_event(signalarea, NULL);
-wavearea_configure_event(wavearea, NULL);
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
 
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-  is_active=0;
-  gtk_widget_destroy(window);
+  GLOBALS->is_active_treesearch_gtk1_c=0;
+  gtk_widget_destroy(GLOBALS->window_treesearch_gtk1_c);
+  GLOBALS->window_treesearch_gtk1_c = NULL;
 }
 
 
@@ -625,7 +600,7 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 /*
  * mainline..
  */
-void treebox(char *title, GtkSignalFunc func)
+void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
 {
     GtkWidget *scrolled_win;
     GtkWidget *hbox;
@@ -635,20 +610,21 @@ void treebox(char *title, GtkSignalFunc func)
     GtkTooltips *tooltips;
     GtkCList  *clist;
 
-    if(is_active) 
+    if(GLOBALS->is_active_treesearch_gtk1_c) 
 	{
-	gdk_window_raise(window->window);
+	gdk_window_raise(GLOBALS->window_treesearch_gtk1_c->window);
 	return;
 	}
 
-    is_active=1;
-    cleanup=func;
+    GLOBALS->is_active_treesearch_gtk1_c=1;
+    GLOBALS->cleanup_treesearch_gtk1_c=func;
 
     /* create a new modal window */
-    window = gtk_window_new(disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW (window), title);
-    gtk_signal_connect(GTK_OBJECT (window), "delete_event",
-                       (GtkSignalFunc) destroy_callback, NULL);
+    GLOBALS->window_treesearch_gtk1_c = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
+    install_focus_cb(GLOBALS->window_treesearch_gtk1_c, ((char *)&GLOBALS->window_treesearch_gtk1_c) - ((char *)GLOBALS));
+
+    gtk_window_set_title(GTK_WINDOW (GLOBALS->window_treesearch_gtk1_c), title);
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c), "delete_event", (GtkSignalFunc) destroy_callback, NULL); 
 
     tooltips=gtk_tooltips_new_2();
 
@@ -663,25 +639,23 @@ void treebox(char *title, GtkSignalFunc func)
                         GTK_FILL | GTK_EXPAND,
                         GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
 
-    tree=gtk_ctree_new(1,0);
-    ctree_main=GTK_CTREE(tree);
-    gtk_clist_set_column_auto_resize (GTK_CLIST (tree), 0, TRUE);
-    gtk_widget_show(tree);
+    GLOBALS->tree_treesearch_gtk1_c=gtk_ctree_new(1,0);
+    GLOBALS->ctree_main=GTK_CTREE(GLOBALS->tree_treesearch_gtk1_c);
 
-    clist=GTK_CLIST(tree);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "select_row",
-                               GTK_SIGNAL_FUNC(select_row_callback),
-                               NULL);
-    gtk_signal_connect_object (GTK_OBJECT (clist), "unselect_row",
-                               GTK_SIGNAL_FUNC(unselect_row_callback),
-                               NULL);
+    gtk_clist_set_column_auto_resize (GTK_CLIST (GLOBALS->tree_treesearch_gtk1_c), 0, TRUE);
+    gtk_widget_show(GLOBALS->tree_treesearch_gtk1_c);
+
+    clist=GTK_CLIST(GLOBALS->tree_treesearch_gtk1_c);
+    gtkwave_signal_connect_object (GTK_OBJECT (clist), "select_row", GTK_SIGNAL_FUNC(select_row_callback), NULL);
+    gtkwave_signal_connect_object (GTK_OBJECT (clist), "unselect_row", GTK_SIGNAL_FUNC(unselect_row_callback), NULL);
 
     gtk_clist_freeze(clist);
     gtk_clist_clear(clist);
 
-    maketree(NULL, treeroot);
+    maketree(NULL, GLOBALS->treeroot);
+
     gtk_clist_thaw(clist);
-    selectedtree=NULL;
+    GLOBALS->selectedtree_treesearch_gtk1_c=NULL;
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_set_usize( GTK_WIDGET (scrolled_win), -1, 300);
@@ -689,10 +663,9 @@ void treebox(char *title, GtkSignalFunc func)
                                       GTK_POLICY_AUTOMATIC,
                                       GTK_POLICY_AUTOMATIC);
     gtk_widget_show(scrolled_win);
-    gtk_container_add (GTK_CONTAINER (scrolled_win), GTK_WIDGET (tree));
+    gtk_container_add (GTK_CONTAINER (scrolled_win), GTK_WIDGET (GLOBALS->tree_treesearch_gtk1_c));
     gtk_container_add (GTK_CONTAINER (frame2), scrolled_win);
 
-
     frameh = gtk_frame_new (NULL);
     gtk_container_border_width (GTK_CONTAINER (frameh), 3);
     gtk_widget_show(frameh);
@@ -706,9 +679,7 @@ void treebox(char *title, GtkSignalFunc func)
 
     button1 = gtk_button_new_with_label ("Append");
     gtk_container_border_width (GTK_CONTAINER (button1), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button1), "clicked",
-			       GTK_SIGNAL_FUNC(ok_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button1), "clicked",  GTK_SIGNAL_FUNC(ok_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     gtk_widget_show (button1);
     gtk_tooltips_set_tip_2(tooltips, button1, 
 		"Add selected signal hierarchy to end of the display on the main window.",NULL);
@@ -717,21 +688,17 @@ void treebox(char *title, GtkSignalFunc func)
 
     button2 = gtk_button_new_with_label (" Insert ");
     gtk_container_border_width (GTK_CONTAINER (button2), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button2), "clicked",
-			       GTK_SIGNAL_FUNC(insert_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button2), "clicked", GTK_SIGNAL_FUNC(insert_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     gtk_widget_show (button2);
     gtk_tooltips_set_tip_2(tooltips, button2, 
 		"Add selected signal hierarchy after last highlighted signal on the main window.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, FALSE, 0);
 
-    if(vcd_explicit_zero_subscripts>=0)
+    if(GLOBALS->vcd_explicit_zero_subscripts>=0)
 	{
     	button3 = gtk_button_new_with_label (" Bundle Up ");
     	gtk_container_border_width (GTK_CONTAINER (button3), 3);
-    	gtk_signal_connect_object (GTK_OBJECT (button3), "clicked",
-			       GTK_SIGNAL_FUNC(bundle_callback_up),
-			       GTK_OBJECT (window));
+    	gtkwave_signal_connect_object (GTK_OBJECT (button3), "clicked", GTK_SIGNAL_FUNC(bundle_callback_up), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     	gtk_widget_show (button3);
     	gtk_tooltips_set_tip_2(tooltips, button3, 
 		"Bundle selected signal hierarchy into a single bit "
@@ -745,9 +712,7 @@ void treebox(char *title, GtkSignalFunc func)
 
     	button3a = gtk_button_new_with_label (" Bundle Down ");
     	gtk_container_border_width (GTK_CONTAINER (button3a), 3);
-    	gtk_signal_connect_object (GTK_OBJECT (button3a), "clicked",
-			       GTK_SIGNAL_FUNC(bundle_callback_down),
-			       GTK_OBJECT (window));
+    	gtkwave_signal_connect_object (GTK_OBJECT (button3a), "clicked", GTK_SIGNAL_FUNC(bundle_callback_down), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     	gtk_widget_show (button3a);
     	gtk_tooltips_set_tip_2(tooltips, button3a, 
 		"Bundle selected signal hierarchy into a single bit "
@@ -762,9 +727,7 @@ void treebox(char *title, GtkSignalFunc func)
 
     button4 = gtk_button_new_with_label (" Replace ");
     gtk_container_border_width (GTK_CONTAINER (button4), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button4), "clicked",
-			       GTK_SIGNAL_FUNC(replace_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button4), "clicked", GTK_SIGNAL_FUNC(replace_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     gtk_widget_show (button4);
     gtk_tooltips_set_tip_2(tooltips, button4, 
 		"Replace highlighted signals on the main window with signals selected above.",NULL);
@@ -772,23 +735,57 @@ void treebox(char *title, GtkSignalFunc func)
 
     button5 = gtk_button_new_with_label (" Exit ");
     gtk_container_border_width (GTK_CONTAINER (button5), 3);
-    gtk_signal_connect_object (GTK_OBJECT (button5), "clicked",
-			       GTK_SIGNAL_FUNC(destroy_callback),
-			       GTK_OBJECT (window));
+    gtkwave_signal_connect_object (GTK_OBJECT (button5), "clicked", GTK_SIGNAL_FUNC(destroy_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     gtk_tooltips_set_tip_2(tooltips, button5, 
 		"Do nothing and return to the main window.",NULL);
     gtk_widget_show (button5);
     gtk_box_pack_start (GTK_BOX (hbox), button5, TRUE, FALSE, 0);
 
     gtk_container_add (GTK_CONTAINER (frameh), hbox);
-    gtk_container_add (GTK_CONTAINER (window), table);
+    gtk_container_add (GTK_CONTAINER (GLOBALS->window_treesearch_gtk1_c), table);
 
-    gtk_widget_show(window);
+    gtk_widget_show(GLOBALS->window_treesearch_gtk1_c);
 }
 
 /*
- * $Id: treesearch_gtk1.c,v 1.2 2007/04/20 02:08:17 gtkwave Exp $
+ * $Id: treesearch_gtk1.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
  * $Log: treesearch_gtk1.c,v $
+ * Revision 1.4  2007/09/12 17:26:45  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.3  2007/09/10 18:08:49  gtkwave
+ * tabs selection can swap dynamically based on external window focus
+ *
+ * Revision 1.2  2007/08/26 21:35:46  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.5  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.4  2007/08/22 02:17:13  gtkwave
+ * gtk1 treebox fixes for re-entrancy
+ *
+ * Revision 1.1.1.1.2.3  2007/08/18 21:51:57  gtkwave
+ * widget destroys and teardown of file formats which use external loaders
+ * and are outside of malloc_2/free_2 control
+ *
+ * Revision 1.1.1.1.2.2  2007/08/07 03:18:55  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.1  2007/08/06 03:50:50  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:58  gtkwave
+ * Imported sources
+ *
+ * Revision 1.4  2007/05/28 00:55:06  gtkwave
+ * added support for arrays as a first class dumpfile datatype
+ *
+ * Revision 1.3  2007/04/29 04:13:49  gtkwave
+ * changed anon union defined in struct Node to a named one as anon unions
+ * are a gcc extension
+ *
  * Revision 1.2  2007/04/20 02:08:17  gtkwave
  * initial release
  *
