@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef WAVE_VLIST_H
 #define WAVE_VLIST_H
 
@@ -23,7 +25,6 @@ unsigned int offs;
 unsigned int elem_siz;
 };
 
-extern int vlist_compression_depth; /* 0-9 zlib value, -1 disables */
 
 
 struct vlist_t *vlist_create(unsigned int elem_siz, unsigned int elem_start_cnt);
@@ -37,8 +38,20 @@ void vlist_uncompress(struct vlist_t **v);
 #endif
 
 /*
- * $Id: vlist.h,v 1.2 2007/04/20 02:08:18 gtkwave Exp $
+ * $Id: vlist.h,v 1.2 2007/08/26 21:35:46 gtkwave Exp $
  * $Log: vlist.h,v $
+ * Revision 1.2  2007/08/26 21:35:46  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:28  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:22  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:18  gtkwave
  * initial release
  *
